=== modified file 'NEWS'
--- NEWS	2009-01-23 21:40:04 +0000
+++ NEWS	2009-02-26 18:10:29 +0000
@@ -6,6 +6,9 @@
     - Loggerhead now serves bzr branches over HTTP and exposes the URL to
       branch them. (Jonathan Lange)
 
+    - Leading blank lines in commit messages no longer result in an empty
+      summary. (Colin Watson)
+
 
 1.10 [22Dec2008]
 ---------------

=== modified file 'README.txt'
--- README.txt	2008-10-02 21:12:58 +0000
+++ README.txt	2009-02-24 21:13:30 +0000
@@ -86,8 +86,8 @@
 configuration is one way to do this::
 
     <Location "/branches/">
-        ProxyPass http://127.0.0.1:8080/
-        ProxyPassReverse http://127.0.0.1:8080/
+        ProxyPass http://127.0.0.1:8080/branches/
+        ProxyPassReverse http://127.0.0.1:8080/branches/
     </Location>
 
 If Paste Deploy is installed, the 'serve-branches' script can be

=== modified file 'loggerhead/__init__.py'
--- loggerhead/__init__.py	2008-12-22 19:54:58 +0000
+++ loggerhead/__init__.py	2009-02-10 21:11:43 +0000
@@ -12,6 +12,19 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-"""Just a simple container to turn this into a python package."""
+"""A simple container to turn this into a python package.
+
+We also check the versions of some dependencies.
+"""
+
+import pkg_resources
+
 __version__ = '1.10'
 required_bzrlib = (1, 6)
+
+pkg_resources.get_distribution('Paste>=1.6')
+try:
+    pkg_resources.get_distribution('PasteDeploy>=1.3')
+except pkg_resources.DistributionNotFound:
+    # No paste.deploy is OK, but an old paste.deploy is bad.
+    pass

=== modified file 'loggerhead/apps/__init__.py'
--- loggerhead/apps/__init__.py	2008-12-05 05:07:33 +0000
+++ loggerhead/apps/__init__.py	2009-02-19 01:24:20 +0000
@@ -4,8 +4,6 @@
 
 from paste import urlparser, fileapp
 
-from bzrlib.plugin import load_plugins
-
 static = os.path.join(
     os.path.dirname(os.path.dirname(__file__)), 'static')
 
@@ -13,6 +11,3 @@
 
 favicon_app = fileapp.FileApp(os.path.join(static, 'images', 'favicon.ico'))
 robots_app = fileapp.FileApp(os.path.join(static, 'robots.txt'))
-
-# load plugins - such as svn:// support, extra formats and so on.
-load_plugins()

=== modified file 'loggerhead/apps/branch.py'
--- loggerhead/apps/branch.py	2009-02-06 05:36:03 +0000
+++ loggerhead/apps/branch.py	2009-02-18 10:36:48 +0000
@@ -23,10 +23,13 @@
 from loggerhead import util
 
 
+_DEFAULT = object()
+
 class BranchWSGIApp(object):
 
     def __init__(self, branch, friendly_name=None, config={},
-                 graph_cache=None, branch_link=None, is_root=False):
+                 graph_cache=None, branch_link=None, is_root=False,
+                 served_url=_DEFAULT):
         self.branch = branch
         self._config = config
         self.friendly_name = friendly_name
@@ -36,6 +39,7 @@
             graph_cache = bzrlib.lru_cache.LRUCache()
         self.graph_cache = graph_cache
         self.is_root = is_root
+        self.served_url = served_url
 
     def get_history(self):
         _history = History(self.branch, self.graph_cache)
@@ -70,11 +74,6 @@
         kw = util.get_context(**kw)
         return self.url(*args, **kw)
 
-    @property
-    def served_url(self):
-        """The URL that you can fetch this branch from."""
-        return self.url([])
-
     def static_url(self, path):
         return self._static_url_base + path
 
@@ -103,6 +102,8 @@
         if self._static_url_base is None:
             self._static_url_base = self._url_base
         self._environ = environ
+        if self.served_url is _DEFAULT:
+            self.served_url = self.url([])
         path = request.path_info_pop(environ)
         if not path:
             raise httpexceptions.HTTPMovedPermanently(

=== modified file 'loggerhead/controllers/__init__.py'
--- loggerhead/controllers/__init__.py	2009-02-06 05:36:03 +0000
+++ loggerhead/controllers/__init__.py	2009-02-11 03:23:45 +0000
@@ -121,7 +121,7 @@
         h = self._history
         if h is None:
             return None
-        if len(self.args) > 0:
+        if len(self.args) > 0 and self.args != ['']:
             return h.fix_revid(self.args[0])
         else:
             return h.last_revid

=== modified file 'loggerhead/controllers/annotate_ui.py'
--- loggerhead/controllers/annotate_ui.py	2008-12-05 18:52:44 +0000
+++ loggerhead/controllers/annotate_ui.py	2009-02-23 02:52:39 +0000
@@ -18,7 +18,10 @@
 #
 
 import os
-import posixpath
+import time
+
+import bzrlib.errors
+import bzrlib.textfile
 
 from paste.httpexceptions import HTTPBadRequest, HTTPServerError
 
@@ -26,19 +29,53 @@
 from loggerhead import util
 
 
-def dirname(path):
-    while path.endswith('/'):
-        path = path[:-1]
-    path = posixpath.dirname(path)
-    return path
-
-
-class AnnotateUI (TemplatedBranchView):
+class AnnotateUI(TemplatedBranchView):
 
     template_path = 'loggerhead.templates.annotate'
 
+    def annotate_file(self, file_id, revid):
+        z = time.time()
+        lineno = 1
+        parity = 0
+
+        file_revid = self._history.get_inventory(revid)[file_id].revision
+        tree = self._history._branch.repository.revision_tree(file_revid)
+
+        try:
+            bzrlib.textfile.check_text_lines(tree.get_file_lines(file_id))
+        except bzrlib.errors.BinaryFile:
+                # bail out; this isn't displayable text
+                yield util.Container(parity=0, lineno=1, status='same',
+                                     text='(This is a binary file.)',
+                                     change=util.Container())
+        else:
+            change_cache = {}
+
+            last_line_revid = None
+            for line_revid, text in tree.annotate_iter(file_id):
+                if line_revid == last_line_revid:
+                    # remember which lines have a new revno and which don't
+                    status = 'same'
+                else:
+                    status = 'changed'
+                    parity ^= 1
+                    last_line_revid = line_revid
+                    if line_revid in change_cache:
+                        change = change_cache[line_revid]
+                    else:
+                        change = self._history.get_changes([line_revid])[0]
+                        change_cache[line_revid] = change
+
+                yield util.Container(
+                    parity=parity, lineno=lineno, status=status,
+                    change=change, text=util.fixed_width(text))
+                lineno += 1
+
+        self.log.debug('annotate: %r secs' % (time.time() - z))
+
     def get_values(self, path, kwargs, headers):
         history = self._history
+        branch = history._branch
         revid = self.get_revid()
         revid = history.fix_revid(revid)
         file_id = kwargs.get('file_id', None)
@@ -58,7 +95,7 @@
 
         change = history.get_changes([ revid ])[0]
         # If we're looking at the tip, use head: in the URL instead
-        if revid == history.last_revid:
+        if revid == branch.last_revision():
             revno_url = 'head:'
         else:
             revno_url = history.get_revno(revid)
@@ -79,16 +116,14 @@
         branch_breadcrumbs = util.branch_breadcrumbs(path, inv, 'files')
 
         return {
-            'revid': revid,
             'revno_url': revno_url,
             'file_id': file_id,
             'path': path,
             'filename': filename,
             'navigation': navigation,
             'change': change,
-            'contents': list(history.annotate_file(file_id, revid)),
+            'contents': list(self.annotate_file(file_id, revid)),
             'fileview_active': True,
             'directory_breadcrumbs': directory_breadcrumbs,
             'branch_breadcrumbs': branch_breadcrumbs,
-            'history': self._history,
         }

=== modified file 'loggerhead/controllers/inventory_ui.py'
--- loggerhead/controllers/inventory_ui.py	2008-12-05 18:52:44 +0000
+++ loggerhead/controllers/inventory_ui.py	2009-02-23 02:34:04 +0000
@@ -22,8 +22,9 @@
 import posixpath
 import urllib
 
-from paste.httpexceptions import HTTPServerError
+from paste.httpexceptions import HTTPNotFound
 
+from bzrlib import errors
 from bzrlib.revision import is_null as is_null_rev
 
 from loggerhead import util
@@ -35,8 +36,7 @@
 
 def dirname(path):
     if path is not None:
-        while path.endswith('/'):
-            path = path[:-1]
+        path = path.rstrip('/')
         path = urllib.quote(posixpath.dirname(path))
     return path
 
@@ -45,42 +45,91 @@
 
     template_path = 'loggerhead.templates.inventory'
 
+    def get_filelist(self, inv, path, sort_type):
+        """
+        return the list of all files (and their attributes) within a given
+        path subtree.
+
+        @param inv: The inventory.
+        @param path: The path of a directory within the inventory.
+        @param sort_type: How to sort the results... XXX.
+        """
+        file_id = inv.path2id(path)
+        dir_ie = inv[file_id]
+        file_list = []
+
+        revid_set = set()
+
+        for filename, entry in dir_ie.children.iteritems():
+            revid_set.add(entry.revision)
+
+        change_dict = {}
+        for change in self._history.get_changes(list(revid_set)):
+            change_dict[change.revid] = change
+
+        for filename, entry in dir_ie.children.iteritems():
+            pathname = filename
+            if entry.kind == 'directory':
+                pathname += '/'
+            if path == '':
+                absolutepath = pathname
+            else:
+                absolutepath = urllib.quote(path + '/' + pathname)
+            revid = entry.revision
+
+            file = util.Container(
+                filename=filename, executable=entry.executable,
+                kind=entry.kind, absolutepath=absolutepath,
+                file_id=entry.file_id, size=entry.text_size, revid=revid,
+                change=change_dict[revid])
+            file_list.append(file)
+
+        if sort_type == 'filename':
+            file_list.sort(key=lambda x: x.filename.lower()) # case-insensitive
+        elif sort_type == 'size':
+            file_list.sort(key=lambda x: x.size)
+        elif sort_type == 'date':
+            file_list.sort(key=lambda x: x.change.date)
+
+        # Always sort directories first.
+        file_list.sort(key=lambda x: x.kind != 'directory')
+
+        return file_list
+
     def get_values(self, path, kwargs, headers):
         history = self._history
-        revid = self.get_revid()
-
+        branch = history._branch
         try:
-            inv = history.get_inventory(revid)
-        except:
-            self.log.exception('Exception fetching changes')
-            raise HTTPServerError('Could not fetch changes')
+            revid = self.get_revid()
+            rev_tree = branch.repository.revision_tree(revid)
+        except errors.NoSuchRevision:
+            raise HTTPNotFound()
 
         file_id = kwargs.get('file_id', None)
         start_revid = kwargs.get('start_revid', None)
-        sort_type = kwargs.get('sort', None)
+        sort_type = kwargs.get('sort', 'filename')
 
         # no navbar for revisions
         navigation = util.Container()
 
-        change = history.get_changes([ revid ])[0]
-        # add parent & merge-point branch-nick info, in case it's useful
-        history.get_branch_nicks([ change ])
-
         if path is not None:
-            if not path.startswith('/'):
-                path = '/' + path
-            file_id = history.get_file_id(revid, path)
+            file_id = rev_tree.path2id(path)
+            if file_id is None:
+                raise HTTPNotFound()
         else:
-            path = inv.id2path(file_id)
-
-        if file_id is None:
-            file_id = inv.root.file_id
+            if file_id is None:
+                path = ''
+            else:
+                try:
+                    path = rev_tree.id2path(file_id)
+                except errors.NoSuchId:
+                    raise HTTPNotFound()
 
         # Are we at the top of the tree
-        if inv.is_root(file_id):
+        if path in ['/', '']:
             updir = None
         else:
-            updir = dirname(path)[1:]
+            updir = dirname(path)
 
         # Directory Breadcrumbs
         directory_breadcrumbs = util.directory_breadcrumbs(
@@ -89,15 +138,10 @@
                 'files')
 
         if not is_null_rev(revid):
-            try:
-                inv = history.get_inventory(revid)
-            except:
-                self.log.exception('Exception fetching changes')
-                raise HTTPServerError('Could not fetch changes')
 
             change = history.get_changes([ revid ])[0]
             # If we're looking at the tip, use head: in the URL instead
-            if revid == history.last_revid:
+            if revid == branch.last_revision():
                 revno_url = 'head:'
             else:
                 revno_url = history.get_revno(revid)
@@ -105,16 +149,14 @@
             history.get_branch_nicks([ change ])
 
             # Create breadcrumb trail for the path within the branch
-            branch_breadcrumbs = util.branch_breadcrumbs(path, inv, 'files')
-            filelist = history.get_filelist(inv, file_id, sort_type)
+            branch_breadcrumbs = util.branch_breadcrumbs(path, rev_tree, 'files')
+            filelist = self.get_filelist(rev_tree.inventory, path, sort_type)
         else:
-            inv = None
-            file_id = None
             start_revid = None
-            sort_type = None
             change = None
             path = "/"
             updir = None
+            revno_url = 'head:'
             branch_breadcrumbs = []
             filelist = []
 
@@ -124,12 +166,9 @@
             'revid': revid,
             'revno_url': revno_url,
             'change': change,
-            'file_id': file_id,
             'path': path,
             'updir': updir,
             'filelist': filelist,
-            'history': history,
-            'posixpath': posixpath,
             'navigation': navigation,
             'url': self._branch.context_url,
             'start_revid': start_revid,

=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2008-12-05 18:52:44 +0000
+++ loggerhead/controllers/revision_ui.py	2009-02-18 01:00:02 +0000
@@ -17,10 +17,15 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+from StringIO import StringIO
+
+import bzrlib.diff
+
 from paste.httpexceptions import HTTPServerError
 
 from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
+from loggerhead.history import rich_filename
 
 
 DEFAULT_LINE_COUNT_LIMIT = 3000
@@ -30,6 +35,121 @@
 
     template_path = 'loggerhead.templates.revision'
 
+    def _process_diff(self, diff):
+        # doesn't really need to be a method; could be static.
+        chunks = []
+        chunk = None
+        for line in diff.splitlines():
+            if len(line) == 0:
+                continue
+            if line.startswith('+++ ') or line.startswith('--- '):
+                continue
+            if line.startswith('@@ '):
+                # new chunk
+                if chunk is not None:
+                    chunks.append(chunk)
+                chunk = util.Container()
+                chunk.diff = []
+                split_lines = line.split(' ')[1:3]
+                lines = [int(x.split(',')[0][1:]) for x in split_lines]
+                old_lineno = lines[0]
+                new_lineno = lines[1]
+            elif line.startswith(' '):
+                chunk.diff.append(util.Container(old_lineno=old_lineno,
+                                                 new_lineno=new_lineno,
+                                                 type='context',
+                                                 line=line[1:]))
+                old_lineno += 1
+                new_lineno += 1
+            elif line.startswith('+'):
+                chunk.diff.append(util.Container(old_lineno=None,
+                                                 new_lineno=new_lineno,
+                                                 type='insert', line=line[1:]))
+                new_lineno += 1
+            elif line.startswith('-'):
+                chunk.diff.append(util.Container(old_lineno=old_lineno,
+                                                 new_lineno=None,
+                                                 type='delete', line=line[1:]))
+                old_lineno += 1
+            else:
+                chunk.diff.append(util.Container(old_lineno=None,
+                                                 new_lineno=None,
+                                                 type='unknown',
+                                                 line=repr(line)))
+        if chunk is not None:
+            chunks.append(chunk)
+        return chunks
+
+    def _parse_diffs(self, old_tree, new_tree, delta):
+        """
+        Return a list of processed diffs, in the format::
+
+            list(
+                filename: str,
+                file_id: str,
+                chunks: list(
+                    diff: list(
+                        old_lineno: int,
+                        new_lineno: int,
+                        type: str('context', 'delete', or 'insert'),
+                        line: str,
+                    ),
+                ),
+            )
+        """
+        process = []
+        out = []
+
+        for old_path, new_path, fid, \
+            kind, text_modified, meta_modified in delta.renamed:
+            if text_modified:
+                process.append((old_path, new_path, fid, kind))
+        for path, fid, kind, text_modified, meta_modified in delta.modified:
+            process.append((path, path, fid, kind))
+
+        for old_path, new_path, fid, kind in process:
+            old_lines = old_tree.get_file_lines(fid)
+            new_lines = new_tree.get_file_lines(fid)
+            buffer = StringIO()
+            if old_lines != new_lines:
+                try:
+                    bzrlib.diff.internal_diff(old_path, old_lines,
+                                              new_path, new_lines, buffer)
+                except bzrlib.errors.BinaryFile:
+                    diff = ''
+                else:
+                    diff = buffer.getvalue()
+            else:
+                diff = ''
+            out.append(util.Container(
+                          filename=rich_filename(new_path, kind),
+                          file_id=fid,
+                          chunks=self._process_diff(diff),
+                          raw_diff=diff))
+
+        return out
+
+    def get_change_with_diff(self, revid, compare_revid):
+        h = self._history
+        change = h.get_changes([revid])[0]
+
+        if compare_revid is None:
+            if change.parents:
+                compare_revid = change.parents[0].revid
+            else:
+                compare_revid = 'null:'
+
+        rev_tree1 = h._branch.repository.revision_tree(compare_revid)
+        rev_tree2 = h._branch.repository.revision_tree(revid)
+        delta = rev_tree2.changes_from(rev_tree1)
+
+        change.changes = h.parse_delta(delta)
+        change.changes.modified = self._parse_diffs(rev_tree1,
+                                                    rev_tree2,
+                                                    delta)
+
+        return change
+
     def get_values(self, path, kwargs, headers):
         h = self._history
         revid = self.get_revid()
@@ -57,7 +177,7 @@
             navigation.query = query
         util.fill_in_navigation(navigation)
 
-        change = h.get_change_with_diff(revid, compare_revid)
+        change = self.get_change_with_diff(revid, compare_revid)
         # add parent & merge-point branch-nick info, in case it's useful
         h.get_branch_nicks([change])
 
@@ -67,12 +187,6 @@
             for chunk in file.chunks:
                 line_count += len(chunk.diff)
 
-        # let's make side-by-side diff be the default
-        # FIXME: not currently in use. Should be
-        side_by_side = not kwargs.get('unified', False)
-        if side_by_side:
-            h.add_side_by_side([change])
-
         # Directory Breadcrumbs
         directory_breadcrumbs = (
             util.directory_breadcrumbs(
@@ -92,7 +206,6 @@
             'query': query,
             'remember': remember,
             'compare_revid': compare_revid,
-            'side_by_side': side_by_side,
             'url': self._branch.context_url,
             'line_count': line_count,
             'line_count_limit': line_count_limit,

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2008-12-28 05:10:10 +0000
+++ loggerhead/history.py	2009-02-26 18:10:29 +0000
@@ -67,67 +67,6 @@
 
 bzrlib.ui.ui_factory = ThreadSafeUIFactory()
 
-
-def _process_side_by_side_buffers(line_list, delete_list, insert_list):
-    while len(delete_list) < len(insert_list):
-        delete_list.append((None, '', 'context'))
-    while len(insert_list) < len(delete_list):
-        insert_list.append((None, '', 'context'))
-    while len(delete_list) > 0:
-        d = delete_list.pop(0)
-        i = insert_list.pop(0)
-        line_list.append(util.Container(old_lineno=d[0], new_lineno=i[0],
-                                        old_line=d[1], new_line=i[1],
-                                        old_type=d[2], new_type=i[2]))
-
-
-def _make_side_by_side(chunk_list):
-    """
-    turn a normal unified-style diff (post-processed by parse_delta) into a
-    side-by-side diff structure.  the new structure is::
-
-        chunks: list(
-            diff: list(
-                old_lineno: int,
-                new_lineno: int,
-                old_line: str,
-                new_line: str,
-                type: str('context' or 'changed'),
-            )
-        )
-    """
-    out_chunk_list = []
-    for chunk in chunk_list:
-        line_list = []
-        wrap_char = '<wbr/>'
-        delete_list, insert_list = [], []
-        for line in chunk.diff:
-            # Add <wbr/> every X characters so we can wrap properly
-            wrap_line = re.findall(r'.{%d}|.+$' % 78, line.line)
-            wrap_lines = [util.html_clean(_line) for _line in wrap_line]
-            wrapped_line = wrap_char.join(wrap_lines)
-
-            if line.type == 'context':
-                if len(delete_list) or len(insert_list):
-                    _process_side_by_side_buffers(line_list, delete_list,
-                                                  insert_list)
-                    delete_list, insert_list = [], []
-                line_list.append(util.Container(old_lineno=line.old_lineno,
-                                                new_lineno=line.new_lineno,
-                                                old_line=wrapped_line,
-                                                new_line=wrapped_line,
-                                                old_type=line.type,
-                                                new_type=line.type))
-            elif line.type == 'delete':
-                delete_list.append((line.old_lineno, wrapped_line, line.type))
-            elif line.type == 'insert':
-                insert_list.append((line.new_lineno, wrapped_line, line.type))
-        if len(delete_list) or len(insert_list):
-            _process_side_by_side_buffers(line_list, delete_list, insert_list)
-        out_chunk_list.append(util.Container(diff=line_list))
-    return out_chunk_list
-
-
 def is_branch(folder):
     try:
         bzrlib.branch.Branch.open(folder)
@@ -143,7 +82,7 @@
     module (Robey, the original author of this code, apparently favored this
     style of message).
     """
-    message = message.splitlines()
+    message = message.lstrip().splitlines()
 
     if len(message) == 1:
         message = textwrap.wrap(message[0])
@@ -654,26 +593,6 @@
         for entry, changes in zip(entries, changes_list):
             entry.changes = changes
 
-    def get_change_with_diff(self, revid, compare_revid=None):
-        change = self.get_changes([revid])[0]
-
-        if compare_revid is None:
-            if change.parents:
-                compare_revid = change.parents[0].revid
-            else:
-                compare_revid = 'null:'
-
-        rev_tree1 = self._branch.repository.revision_tree(compare_revid)
-        rev_tree2 = self._branch.repository.revision_tree(revid)
-        delta = rev_tree2.changes_from(rev_tree1)
-
-        change.changes = self.parse_delta(delta)
-        change.changes.modified = self._parse_diffs(rev_tree1,
-                                                    rev_tree2,
-                                                    delta)
-
-        return change
-
     def get_file(self, file_id, revid):
         "returns (path, filename, data)"
         inv = self.get_inventory(revid)
@@ -684,100 +603,6 @@
             path = '/' + path
         return path, inv_entry.name, rev_tree.get_file_text(file_id)
 
-    def _parse_diffs(self, old_tree, new_tree, delta):
-        """
-        Return a list of processed diffs, in the format::
-
-            list(
-                filename: str,
-                file_id: str,
-                chunks: list(
-                    diff: list(
-                        old_lineno: int,
-                        new_lineno: int,
-                        type: str('context', 'delete', or 'insert'),
-                        line: str,
-                    ),
-                ),
-            )
-        """
-        process = []
-        out = []
-
-        for old_path, new_path, fid, \
-            kind, text_modified, meta_modified in delta.renamed:
-            if text_modified:
-                process.append((old_path, new_path, fid, kind))
-        for path, fid, kind, text_modified, meta_modified in delta.modified:
-            process.append((path, path, fid, kind))
-
-        for old_path, new_path, fid, kind in process:
-            old_lines = old_tree.get_file_lines(fid)
-            new_lines = new_tree.get_file_lines(fid)
-            buffer = StringIO()
-            if old_lines != new_lines:
-                try:
-                    bzrlib.diff.internal_diff(old_path, old_lines,
-                                              new_path, new_lines, buffer)
-                except bzrlib.errors.BinaryFile:
-                    diff = ''
-                else:
-                    diff = buffer.getvalue()
-            else:
-                diff = ''
-            out.append(util.Container(
-                          filename=rich_filename(new_path, kind),
-                          file_id=fid,
-                          chunks=self._process_diff(diff),
-                          raw_diff=diff))
-
-        return out
-
-    def _process_diff(self, diff):
-        # doesn't really need to be a method; could be static.
-        chunks = []
-        chunk = None
-        for line in diff.splitlines():
-            if len(line) == 0:
-                continue
-            if line.startswith('+++ ') or line.startswith('--- '):
-                continue
-            if line.startswith('@@ '):
-                # new chunk
-                if chunk is not None:
-                    chunks.append(chunk)
-                chunk = util.Container()
-                chunk.diff = []
-                split_lines = line.split(' ')[1:3]
-                lines = [int(x.split(',')[0][1:]) for x in split_lines]
-                old_lineno = lines[0]
-                new_lineno = lines[1]
-            elif line.startswith(' '):
-                chunk.diff.append(util.Container(old_lineno=old_lineno,
-                                                 new_lineno=new_lineno,
-                                                 type='context',
-                                                 line=line[1:]))
-                old_lineno += 1
-                new_lineno += 1
-            elif line.startswith('+'):
-                chunk.diff.append(util.Container(old_lineno=None,
-                                                 new_lineno=new_lineno,
-                                                 type='insert', line=line[1:]))
-                new_lineno += 1
-            elif line.startswith('-'):
-                chunk.diff.append(util.Container(old_lineno=old_lineno,
-                                                 new_lineno=None,
-                                                 type='delete', line=line[1:]))
-                old_lineno += 1
-            else:
-                chunk.diff.append(util.Container(old_lineno=None,
-                                                 new_lineno=None,
-                                                 type='unknown',
-                                                 line=repr(line)))
-        if chunk is not None:
-            chunks.append(chunk)
-        return chunks
-
     def parse_delta(self, delta):
         """
         Return a nested data structure containing the changes in a delta::
@@ -815,107 +640,3 @@
 
         return util.Container(added=added, renamed=renamed,
                               removed=removed, modified=modified)
-
-    @staticmethod
-    def add_side_by_side(changes):
-        # FIXME: this is a rotten API.
-        for change in changes:
-            for m in change.changes.modified:
-                m.sbs_chunks = _make_side_by_side(m.chunks)
-
-    def get_filelist(self, inv, file_id, sort_type=None):
-        """
-        return the list of all files (and their attributes) within a given
-        path subtree.
-        """
-
-        dir_ie = inv[file_id]
-        path = inv.id2path(file_id)
-        file_list = []
-
-        revid_set = set()
-
-        for filename, entry in dir_ie.children.iteritems():
-            revid_set.add(entry.revision)
-
-        change_dict = {}
-        for change in self.get_changes(list(revid_set)):
-            change_dict[change.revid] = change
-
-        for filename, entry in dir_ie.children.iteritems():
-            pathname = filename
-            if entry.kind == 'directory':
-                pathname += '/'
-            if path == '':
-                absolutepath = pathname
-            else:
-                absolutepath = urllib.quote(path + '/' + pathname)
-            revid = entry.revision
-
-            file = util.Container(
-                filename=filename, executable=entry.executable,
-                kind=entry.kind, pathname=pathname, absolutepath=absolutepath,
-                file_id=entry.file_id, size=entry.text_size, revid=revid,
-                change=change_dict[revid])
-            file_list.append(file)
-
-        if sort_type == 'filename' or sort_type is None:
-            file_list.sort(key=lambda x: x.filename.lower()) # case-insensitive
-        elif sort_type == 'size':
-            file_list.sort(key=lambda x: x.size)
-        elif sort_type == 'date':
-            file_list.sort(key=lambda x: x.change.date)
-
-        # Always sort by kind to get directories first
-        file_list.sort(key=lambda x: x.kind != 'directory')
-
-        parity = 0
-        for file in file_list:
-            file.parity = parity
-            parity ^= 1
-
-        return file_list
-
-    def annotate_file(self, file_id, revid):
-        z = time.time()
-        lineno = 1
-        parity = 0
-
-        file_revid = self.get_inventory(revid)[file_id].revision
-        oldvalues = None
-        tree = self._branch.repository.revision_tree(file_revid)
-        revid_set = set()
-
-        try:
-            bzrlib.textfile.check_text_lines(tree.get_file_lines(file_id))
-        except bzrlib.errors.BinaryFile:
-                # bail out; this isn't displayable text
-                yield util.Container(parity=0, lineno=1, status='same',
-                                     text='(This is a binary file.)',
-                                     change=util.Container())
-        else:
-            for line_revid, text in tree.annotate_iter(file_id):
-                revid_set.add(line_revid)
-
-            change_cache = dict([(c.revid, c) \
-                    for c in self.get_changes(list(revid_set))])
-
-            last_line_revid = None
-            for line_revid, text in tree.annotate_iter(file_id):
-                if line_revid == last_line_revid:
-                    # remember which lines have a new revno and which don't
-                    status = 'same'
-                else:
-                    status = 'changed'
-                    parity ^= 1
-                    last_line_revid = line_revid
-                    change = change_cache[line_revid]
-                    trunc_revno = change.revno
-                    if len(trunc_revno) > 10:
-                        trunc_revno = trunc_revno[:9] + '...'
-
-                yield util.Container(parity=parity, lineno=lineno, status=status,
-                                     change=change, text=util.fixed_width(text))
-                lineno += 1
-
-        self.log.debug('annotate: %r secs' % (time.time() - z))

=== modified file 'loggerhead/static/css/diff.css'
--- loggerhead/static/css/diff.css	2009-01-23 19:19:39 +0000
+++ loggerhead/static/css/diff.css	2009-02-26 20:55:46 +0000
@@ -1,137 +1,151 @@
 /*Info Box*/
 .infoContainer {
-	width:970px;
-	padding:10px 10px 0px 10px;
-	margin:0px 0px 10px 0px;
-	color:#666;
-	background:#fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
-	border:1px solid #b7b7b7;
+    width:970px;
+    padding:10px 10px 0px 10px;
+    margin:0px 0px 10px 0px;
+    color:#666;
+    background:#fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
+    border:1px solid #b7b7b7;
 }
 ul#list-files {
-	float:right;
-	width:460px;
-	list-style:none;
-	margin:0px;
-	padding:0px;
-	font:normal 11px/normal sans-serif;
-	color:#000;
+    float:right;
+    width:460px;
+    list-style:none;
+    margin:0px;
+    padding:0px;
+    font:normal 11px/normal sans-serif;
+    color:#000;
 }
 ul#list-files li {
-	width:440px;
-	padding:2px 0px 2px 20px;
-	margin:0px 0px 2px 8px;
-	background:url(../images/ico_file.gif) 2px 0px no-repeat;
+    width:440px;
+    padding:2px 0px 2px 20px;
+    margin:0px 0px 2px 8px;
+    background:url(../images/ico_file.gif) 2px 0px no-repeat;
 }
 ul#list-files li.desc {
     margin-left: 0;
-	background:url(../images/ico_description.gif) 0px 0px no-repeat;
+    background:url(../images/ico_description.gif) 0px 0px no-repeat;
 }
 #infTxt {
-	float:left;
-	width:493px;
-	margin:0px 0px 5px 0px;
+    float:left;
+    width:493px;
+    margin:0px 0px 5px 0px;
 }
 .information, .committer, .timer, .mfrom, .mto, .revid {
-	clear:both;
-	margin:0px;
-	padding:0px 0px 2px 18px;
-	font:normal 11px/1.3 sans-serif;
-	color:#666;
-	background:url(../images/ico_description.gif) no-repeat top left;
+    clear:both;
+    margin:0px;
+    padding:0px 0px 2px 18px;
+    font:normal 11px/1.3 sans-serif;
+    color:#666;
+    background:url(../images/ico_description.gif) no-repeat top left;
 }
 .revid {
     padding:1px 0px 0px 18px;
     margin:0px 10px 5px 0px;
 }
 .committer, .mfrom, .mto {
-	color:#000;
-	padding:1px 0px 0px 18px;
-	margin:0px 10px 5px 0px;
-	float:left;
-	display:inline;
-	background:url(../images/ico_committer.gif) no-repeat 2px 0px;
+    color:#000;
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+    float:left;
+    display:inline;
+    background:url(../images/ico_committer.gif) no-repeat 2px 0px;
 }
 .timer {
-	margin:0px 10px 5px 0px;
-	padding:1px 0px 0px 18px;
-	float:left;
-	clear:none;
-	display:inline;
-	background:url(../images/ico_time.gif) no-repeat top left;
+    margin:0px 10px 5px 0px;
+    padding:1px 0px 0px 18px;
+    float:left;
+    clear:none;
+    display:inline;
+    background:url(../images/ico_time.gif) no-repeat top left;
 }
 .mfrom {
-	background:url(../images/ico_mergefrom.gif) no-repeat top left;
+    background:url(../images/ico_mergefrom.gif) no-repeat top left;
 }
 .mto {
-	background:url(../images/ico_mergeto.gif) no-repeat top left;
+    background:url(../images/ico_mergeto.gif) no-repeat top left;
 }
 /**/
 #loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
-	color:#0f6b97;
-	text-decoration:none;
-	margin-right:10px;
-	float:left;	
+    color:#0f6b97;
+    text-decoration:none;
+    margin-right:10px;
+    float:left;
 }
 #loggerheadCont p.codin, #loggerheadCont p.codin a, #loggerheadCont p.codin a:link, #loggerheadCont p.codin a:visited, #loggerheadCont p.codin a:hover {
-	color:#000;
-	font-size:12px;
-	text-decoration:none;
-	margin-right:10px;
-	float:left;	
+    color:#000;
+    font-size:12px;
+    text-decoration:none;
+    margin-right:10px;
+    float:left;
 }
 /*Diff Boxes*/
 .diffBox {
-	width:100%;
-	padding:6px 0%;
-	background:#eef6fa;
-	border:1px solid #d2d2d2;
-	margin:10px 0px 0px 0px;
+    width:100%;
+    padding:6px 0%;
+    background:#eef6fa;
+    border:1px solid #d2d2d2;
+    margin:10px 0px 0px 0px;
 }
 .diffBox img {
-	vertical-align:middle;
+    vertical-align:middle;
 }
 .diffBox a, .diffBox a:link, .diffBox a:visited, .diffBox a:hover {
-	text-decoration:none;
+    text-decoration:none;
 }
 .diff {
     margin: 2em 0 2em 0;
 }
+.diffinfo {
+    overflow: hidden;
+}
 .lineNumber {
-	float:left;
-	width:2%;
-	padding:0px 1%; 
-	border-right:1px solid #d5d5d5;
-	border-left:1px solid #d5d5d5;
-	color:#000;
-	background:#f8fbfd;
-	font:normal 12px/1.8 monospace;
-	text-align:right;
-}
-.lineCode, .removecode, .addcode {
-	float:left;
-	width:43%;
-	padding:0px 1%; 
-	color:#000;
-	background:#fff;
-	font:normal 12px/1.8 monospace;
-}
-.delete, .insert {
-	display:block;
-	background:#ff7f7f;
-}
-.insert {
-	background:#92ed92;
+    width:2%;
+    border-right:1px solid #d5d5d5;
+    border-left:1px solid #d5d5d5;
+    background:#f8fbfd;
+    text-align:right;
+}
+.unified .lineNumber.second {
+    border-left:0px;
+}
+.code, .lineNumber {
+    float:left;
+    padding:0px 1%;
+    color:#000;
+    font:normal 12px/1.8 monospace;
+}
+.blank {
+    float: left;
+    padding:0px 1%;
+}
+.unified .code { width:89%; }
+.sbs .code, .blank {
+    width:43%;
+    overflow: hidden;
+}
+.unified .insert-row .lineNumber.first {
+    background:#c9ffc9;
+}
+.unified .delete-row .lineNumber.second {
+    background:#ffbfbf;
+}
+.code.insert, .insert-row .lineNumber.second, .both-row .lineNumber.second {
+    background:#92ed92;
+}
+.code.delete, .delete-row .lineNumber.first, .both-row .lineNumber.first {
+    background:#ff7f7f;
 }
 .separate {
     height: 2em;
     background: #e3e3e3;
 }
 ul#pages {
-	margin-top:10px;
+    margin-top:10px;
 }
 /*Foot Links*/
 #loggerheadCont p.lpandbzr {
-	float:left;
-	padding:3px 0px 0px 0px;
-	margin-top:10px;
+    float:left;
+    padding:3px 0px 0px 0px;
+    margin-top:10px;
 }

=== modified file 'loggerhead/static/css/global.css'
--- loggerhead/static/css/global.css	2009-01-23 20:53:40 +0000
+++ loggerhead/static/css/global.css	2009-02-20 03:13:57 +0000
@@ -337,3 +337,9 @@
 	background:#fcfcfc;
 	border:1px solid #b7b7b7;
 }
+.show_if_js {
+    display: none;
+}
+.revision_log {
+    overflow: hidden;
+}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/changelog.js'
--- loggerhead/static/javascript/changelog.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/changelog.js	2009-02-20 03:30:31 +0000
@@ -0,0 +1,68 @@
+function toggle_expand_all(action)
+{
+  var revlogs = Y.all('.revision_log');
+  if (revlogs == null) return;
+  revlogs.each(
+    function(item, i)
+    {
+      var collapsable = item.collapsable;
+      if(action == 'close')
+      {
+        Y.get('#expand_all').setStyle('display','block');
+        Y.get('#collapse_all').setStyle('display','none');
+        collapsable.close();
+      }
+      else if(action == 'open')
+      {
+        Y.get('#expand_all').setStyle('display','none');
+        Y.get('#collapse_all').setStyle('display','block');
+        collapsable.open();
+      }
+    });
+}
+
+Y.on(
+  'click',
+  function (event) {
+    event.preventDefault();
+    toggle_expand_all('open');
+  },
+  '#expand_all a'
+);
+
+Y.on(
+  'click',
+  function (event) {
+    event.preventDefault();
+    toggle_expand_all('close');
+  },
+  '#collapse_all a'
+);
+
+Y.on(
+  "domready", function () {
+    Y.all(".show_if_js").removeClass("show_if_js");
+  });
+
+Y.on(
+  'domready',
+  function()
+  {
+    var revlogs = Y.all('.revision_log');
+    if (revlogs == null) return;
+    revlogs.each(
+      function(item, i)
+      {
+        var item_slide = item.query('.revisioninfo');
+        var open_content  = new Array();
+        var close_content = new Array();
+        open_content.push(item.query('.long_description'));
+        close_content.push(item.query('.short_description'));
+        var expand_icon = item.query('.expand_icon');
+        var collapsable = new Collapsable(item_slide, expand_icon, open_content, close_content, false);
+
+        item.query('.expand_revisioninfo').on('click',function(){collapsable.toggle();});
+        item.collapsable = collapsable;
+      });
+
+  });

=== modified file 'loggerhead/static/javascript/custom.js'
--- loggerhead/static/javascript/custom.js	2008-11-26 14:16:27 +0000
+++ loggerhead/static/javascript/custom.js	2009-02-26 01:04:18 +0000
@@ -1,248 +1,204 @@
+Y = YUI().use("node", "io-base", "anim");
+
 var global_timeout_id = null;
 var global_search_request = null;
 
-window.addEvent('domready', function() 
-{
-    var search_box = $('q');
-    if ($defined(search_box))
+Y.on(
+  'domready',
+  function()
+  {
+    var search_box = Y.get('#q');
+    if (!Y.Lang.isNull(search_box))
     {
-        search_box.removeEvents();
-        search_box.addEvents(
-        {
-            keyup: function()
-            {
-                if($('q').value == '')
-                {
-                    $('search_terms').setStyle('display','none');
-                }
-                else
-                {
-                    if (null != global_timeout_id)
-                    {
-                        clearTimeout(global_timeout_id);
-                    }
-                        global_timeout_id = setTimeout('$("q").fireEvent("search",$("q").value)',200);
-                }
-            },
-
-            search: function(query)
-            {
-                url = global_path + 'search?query=' + query;
-
-                if ($defined(global_search_request))
-                {
-                    global_search_request.cancel();
-                }
-                global_search_request = new Request({'url':url,'method':'get','onComplete':function(response)
-                  {
-                     cool_search(response,query);
-                 }});
-
-                global_search_request.send('');
-                var posicion = search_box.getPosition();
-                var size     = search_box.getSize();
-
-                $('search_terms').setStyle('position','absolute');
-                $('search_terms').setStyle('left',posicion.x);
-                $('search_terms').setStyle('top',posicion.y + size.y);
-                $('search_terms').setStyle('display','block');
-                $('search_terms').set('html','Loading...');
-
-                new Request({'url':url,'method':'get','onComplete':cool_search}).send('');
-
-
+      function get_suggestions() {
+        var query = search_box.get('value');
+        var url = global_path + 'search?query=' + query;
+
+        if (!Y.Lang.isNull(global_search_request))
+        {
+          global_search_request.abort();
+        }
+        global_search_request = Y.io(
+          url,
+          {
+            on: {complete: cool_search},
+            arguments: [query]
+          }
+        );
+
+        var region = search_box.get('region');
+        var current_query = search_box.get('value');
+
+        Y.get('#search_terms').setStyle('display', 'block');
+        Y.get('#search_terms').setStyle('position', 'absolute');
+        Y.get('#search_terms').setStyle('left', region.left);
+        Y.get('#search_terms').setStyle('top', region.bottom);
+        Y.get('#search_terms').set('innerHTML','Loading...');
+      }
+      search_box.on(
+        "keyup",
+        function(event)
+        {
+          if(search_box.get('value') == '')
+          {
+            Y.get('#search_terms').setStyle('display', 'none');
+          }
+          else
+          {
+            if (null != global_timeout_id)
+            {
+              clearTimeout(global_timeout_id);
             }
+            global_timeout_id = setTimeout(get_suggestions, 200);
+          }
         });
     }
-});
+  });
 
-function cool_search(response, query)
+function cool_search(tid, response, query)
 {
-	var posicion = $('q').getPosition();
-	var size     = $('q').getSize();
-    var current_query = $('q').get('value');
-    if (current_query == query)
-    {
-	    $('search_terms').set('html',response);
-	    $('search_terms').setStyle('display','block');
-	    $('search_terms').setStyle('position','absolute');
-	    $('search_terms').setStyle('left',posicion.x);
-	    $('search_terms').setStyle('top',posicion.y + size.y);
-    }
+  var q = Y.get('#q');
+  var region = q.get('region');
+  var current_query = q.get('value');
+  if (current_query == query)
+  {
+    Y.get('#search_terms').set('innerHTML', response.responseText);
+    Y.get('#search_terms').setStyle('display', 'block');
+    Y.get('#search_terms').setStyle('position', 'absolute');
+    Y.get('#search_terms').setStyle('left', region.left);
+    Y.get('#search_terms').setStyle('top', region.bottom);
+  }
 }
 
 function hide_search()
 {
-    hide_div = setTimeout("$('search_terms').setStyle('display','none')", 300);
-}
-var Colapsable = new Class({
-    initialize: function(item,expand_icon,open_content,close_content,is_open)
-    {
-        this.is_open = false;
-        if ($defined(is_open))
-        {
-            this.is_open = is_open;
-        }
-        this.item = item;
-        item.set('colapsable',this);
-        this.open_content  = open_content;
-        this.close_content = close_content;
-        this.expand_icon   = expand_icon;
-
-        var expander = new Fx.Slide(this.item, { duration: 200 } );
-        if (!this.is_open)
-        {
-            expander.hide();
-            if ($defined(this.expand_icon))
-            {
-                this.expand_icon.set('src',this.expand_icon.title);
-            }
-        }
-        else
-        {
-            if ($defined(this.expand_icon))
-            {
-                this.expand_icon.set('src',this.expand_icon.alt);
-            }
-        }
-    },
-
-    open: function()
-    {
-        this.item.setStyle('display', 'block');
-        var expander = this.item.get('slide');
-        expander.slideIn();
-        if ($defined(this.open_content))
-        {
-            for (var i=0;i<this.open_content.length;++i)
-            {
-                this.open_content[i].setStyle('display','block');
-            }
-		}
-		
-        if ($defined(this.close_content))
-        {
-            for (var i=0;i<this.close_content.length;++i)
-            {
-                this.close_content[i].setStyle('display','none');
-            }
-        }
-
-        if ($defined(this.expand_icon))
-        {
-            this.expand_icon.set('src',this.expand_icon.alt);
-        }
-        this.is_open = true;
-    },
-
-    close: function()
-    {
-        var expander = this.item.get('slide');
-        expander.slideOut();
-        if ($defined(this.open_content))
-        {
-            for (var i=0;i<this.open_content.length;++i)
-            {
-                this.open_content[i].setStyle('display','none');
-            }
-        }
-
-        if ($defined(this.close_content))
-        {
-            for (var i=0;i<this.close_content.length;++i)
-            {
-                this.close_content[i].setStyle('display','block');
-            }
-        }
-        if ($defined(this.expand_icon))
-        {
-            this.expand_icon.set('src',this.expand_icon.title);
-        }
-        this.is_open = false;
-    },
-
-    isOpen : function()
-    {
-        return this.is_open;
-    },
-
-    toggle: function()
-    {
-        if (this.isOpen())
-        {
-            this.close();
-        }
-        else
-        {
-            this.open();
-        }
-    }
-    });
-
-
-window.addEvent('domready', function()
-{
-    $$('.revision_log').each(function(item, i)
-    {
-        var item_slide = item.getElement('.revisioninfo');
-        var open_content  = new Array();
-        var close_content = new Array();
-        open_content.push(item.getElement('.long_description'));
-        close_content.push(item.getElement('.short_description'));
-        var expand_icon = item.getElement('.expand_icon');
-        var colapsable = new Colapsable(item_slide,expand_icon,open_content,close_content);
-        
-        item.getElement('.expand_revisioninfo').addEvent('click',function(){colapsable.toggle();});
-        item.colapsable = colapsable;
-    });
-
-    $$('.diffBox').each(function(item, i)
-    {
-        var item_slide = item.getNext('.diffinfo');
-        var expand_icon = item.getElement( '.expand_diff' );
-        var colapsable = new Colapsable(item_slide,expand_icon,null,null,true);
-        item.getElement( '.expand_diff' ).addEvent( 'click', function(){colapsable.toggle();});
-        item.colapsable=colapsable;
-    });
-});
-
-function toggle_expand_all(action)
-{
-    $$('.revision_log').each(function(item, i)
-    {
-    	var colapsable = item.colapsable;
-        if(action == 'close')
-        {
-            $('expand_all').setStyle('display','block');
-            $('collapse_all').setStyle('display','none');
-            colapsable.close();
-        }
-        else if(action == 'open')
-        {
-            $('expand_all').setStyle('display','none');
-            $('collapse_all').setStyle('display','block');
-            colapsable.open();
-        }
-    });
-}
-
-function toggle_expand_all_revisionview(action)
-{
-    $$('.diffBox').each(function(item, i)
-    {
-    	var colapsable = item.colapsable;
-        if(action == 'close')
-        {
-            $('expand_all').setStyle('display','block');
-            $('collapse_all').setStyle('display','none');
-            colapsable.close();
-        }
-        else if(action == 'open')
-        {
-            $('expand_all').setStyle('display','none');
-            $('collapse_all').setStyle('display','block');
-            colapsable.open();
-        }
-    });
-}
+  setTimeout("Y.get('#search_terms').setStyle('display','none')", 300);
+}
+
+function Collapsable(item, expand_icon, open_content, close_content, is_open)
+{
+  this.is_open = is_open;
+  this.item = item;
+  this.open_content  = open_content;
+  this.close_content = close_content;
+  this.expand_icon   = expand_icon;
+
+  if (this.is_open) {
+    this.height = item.get('region').height;
+  }
+  else {
+    this.height = null;
+  }
+
+  //var expander = new Fx.Slide(this.item, { duration: 200 } );
+  if (!this.is_open)
+  {
+    this.expand_icon.set('src',this.expand_icon.get('title'));
+  }
+  else
+  {
+    this.expand_icon.set('src',this.expand_icon.get('alt'));
+  }
+}
+
+function get_height(node) {
+  node.setStyle('position', 'absolute');
+  node.setStyle('top', -1000000000);
+  node.setStyle('display', 'block');
+  var height = node.get('region').height;
+  node.setStyle('display', 'none');
+  node.setStyle('position', 'static');
+  node.setStyle('top', 'auto');
+  return height;
+}
+
+Collapsable.prototype.open = function()
+{
+  if (this.height == null) {
+    this.height = get_height(this.item);
+  }
+
+  var anim = new Y.Anim(
+    {
+      node: this.item,
+      from: {
+        height: 0
+      },
+      to: {
+        height: this.height
+      },
+      duration: 0.2
+    });
+  anim.on('end', this.openComplete, this);
+  this.item.setStyle('height', 0);
+  this.item.setStyle('display', 'block');
+  anim.run();
+};
+
+Collapsable.prototype.openComplete = function()
+{
+  for (var i=0;i<this.open_content.length;++i)
+  {
+    this.open_content[i].setStyle('display','block');
+  }
+
+  for (var i=0;i<this.close_content.length;++i)
+  {
+    this.close_content[i].setStyle('display','none');
+  }
+
+  this.expand_icon.set('src',this.expand_icon.get('alt'));
+  this.is_open = true;
+};
+
+Collapsable.prototype.close = function()
+{
+  var item = this.item;
+  var anim = new Y.Anim(
+    {
+      node: this.item,
+      from: {
+        height: this.height
+      },
+      to: {
+        height: 0
+      },
+      duration: 0.2
+    });
+  anim.on("end", this.closeComplete, this);
+  anim.run();
+};
+
+Collapsable.prototype.closeComplete = function () {
+  this.item.setStyle('display', 'none');
+  var i;
+  for (i=0;i<this.open_content.length;++i)
+  {
+    this.open_content[i].setStyle('display','none');
+  }
+
+  for (i=0;i<this.close_content.length;++i)
+  {
+    this.close_content[i].setStyle('display','block');
+  }
+  this.expand_icon.set('src',this.expand_icon.get('title'));
+  this.is_open = false;
+};
+
+Collapsable.prototype.isOpen = function()
+{
+  return this.is_open;
+};
+
+Collapsable.prototype.toggle = function()
+{
+  if (this.isOpen())
+  {
+    this.close();
+  }
+  else
+  {
+    this.open();
+  }
+};
 

=== added file 'loggerhead/static/javascript/diff.js'
--- loggerhead/static/javascript/diff.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/diff.js	2009-02-26 02:06:31 +0000
@@ -0,0 +1,160 @@
+var unified = true;
+
+function make_unified(chunk) {
+  var pending_added = [];
+  function flush_adds(before) {
+    for (var i = 0; i < pending_added.length; i++) {
+      before.ancestor().insertBefore(pending_added[i], before);
+    }
+    pending_added.length = 0;
+  }
+  chunk.get('children').filter(".pseudorow").each(
+    function (line) {
+      if (line.hasClass("context-row")) {
+        flush_adds(line);
+        line.removeChild(line.query('.code'));
+      }
+      else if (line.hasClass("both-row")) {
+        var added_line = line.create('<div class="pseudorow insert-row"><div class="lineNumber first">&nbsp;</div><div class="clear">&nbsp;</div></div>');
+        var clear = added_line.query('.clear');
+        added_line.insertBefore(line.query('.lineNumber.second'), clear);
+        added_line.insertBefore(line.query('.code.insert'), clear);
+        pending_added[pending_added.length] = added_line;
+        line.insertBefore(line.create('<div class="lineNumber second">&nbsp;</div>'), line.query('.code.delete'));
+        line.replaceClass("both-row", "delete-row");
+      }
+      else if (line.hasClass("insert-row")) {
+        flush_adds(line);
+        line.removeChild(line.query('.blank'));
+      }
+      else if (line.hasClass("delete-row")) {
+        line.removeChild(line.query('.blank'));
+        line.insertBefore(line.query('.lineNumber.second'), line.query('.code.delete'));
+      }
+    });
+  flush_adds(null);
+  chunk.replaceClass('sbs', 'unified');
+}
+
+function make_sbs(chunk) {
+  var added = [];
+  var removed = [];
+  function clear_bufs(before) {
+    if (!added.length && !removed.length) return;
+    Y.log('hai');
+    var common = Math.min(added.length, removed.length);
+    for (var i = 0; i < common; i++) {
+      var a = added[i];
+      var r = removed[i];
+      a.ancestor().removeChild(a);
+      r.removeChild(r.query('.lineNumber.second'));
+      r.insertBefore(a.query('.lineNumber.second'), r.query('.clear'));
+      r.insertBefore(a.query('.code.insert'), r.query('.clear'));
+      r.replaceClass('removed-row', 'both-row');
+    }
+    if (added.length > removed.length) {
+      for (var j = common; j < added.length; j++) {
+        a = added[j];
+        a.insertBefore(a.create('<div class="blank">&nbsp;</div>'), a.query('.lineNumber.second'));
+      }
+    }
+    else if (added.length < removed.length) {
+      for (var j = common; j < removed.length; j++) {
+        r = removed[j];
+        r.insertBefore(r.query('.code.delete'), r.query('.lineNumber.second'));
+        r.insertBefore(r.create('<div class="blank">&nbsp;</div>'), r.query('.clear'));
+      }
+    }
+    added.length = 0;
+    removed.length = 0;
+  }
+  chunk.get('children').filter(".pseudorow").each(
+    function (line) {
+      if (line.hasClass("context-row")) {
+        clear_bufs(line);
+        line.insertBefore(line.query('.code').cloneNode(true), line.query(".second"));
+      }
+      else if (line.hasClass("insert-row")) {
+        added[added.length] = line;
+      }
+      else if (line.hasClass("delete-row")) {
+        removed[removed.length] = line;
+      }
+    });
+  clear_bufs(null);
+  chunk.replaceClass('unified', 'sbs');
+
+}
+
+function toggle_unified_sbs(event) {
+  event.preventDefault();
+  if (unified) {
+    Y.all(".pseudotable").each(make_sbs);
+    unified = false;
+    Y.get("#toggle_unified_sbs").set('innerHTML', "Show unified diffs");
+  }
+  else {
+    Y.all(".pseudotable").each(make_unified);
+    unified = true;
+    Y.get("#toggle_unified_sbs").set('innerHTML', "Show diffs side-by-side");
+  }
+}
+
+Y.on("click", toggle_unified_sbs, '#toggle_unified_sbs');
+
+function toggle_expand_all_revisionview(action)
+{
+  var diffs = Y.all('.diffBox');
+  if (diffs == null) return;
+  diffs.each(
+    function(item, i)
+    {
+      var collapsable = item.collapsable;
+      if(action == 'close')
+      {
+        Y.get('#expand_all').setStyle('display','block');
+        Y.get('#collapse_all').setStyle('display','none');
+        collapsable.close();
+      }
+      else if(action == 'open')
+      {
+        Y.get('#expand_all').setStyle('display','none');
+        Y.get('#collapse_all').setStyle('display','block');
+        collapsable.open();
+      }
+    });
+}
+
+Y.on(
+  'click',
+  function (event) {
+    event.preventDefault();
+    toggle_expand_all_revisionview('open');
+  },
+  '#expand_all a'
+);
+
+Y.on(
+  'click',
+  function (event) {
+    event.preventDefault();
+    toggle_expand_all_revisionview('close');
+  },
+  '#collapse_all a'
+);
+
+Y.on(
+  "domready", function () {
+    Y.all(".show_if_js").removeClass("show_if_js");
+    var diffs = Y.all('.diffBox');
+    if (diffs == null) return;
+    diffs.each(
+      function(item, i)
+      {
+        var item_slide = item.next('.diffinfo');
+        var expand_icon = item.query( '.expand_diff' );
+        var collapsable = new Collapsable(item_slide, expand_icon, [], [], true);
+        item.query('.expand_diff').on('click', function(){collapsable.toggle();});
+        item.collapsable=collapsable;
+      });
+  });

=== removed file 'loggerhead/static/javascript/mootools-1.2-core.js'
--- loggerhead/static/javascript/mootools-1.2-core.js	2008-06-13 23:50:23 +0000
+++ loggerhead/static/javascript/mootools-1.2-core.js	1970-01-01 00:00:00 +0000
@@ -1,333 +0,0 @@
-//MooTools, <http://mootools.net>, My Object Oriented (JavaScript) Tools. Copyright (c) 2006-2008 Valerio Proietti, <http://mad4milk.net>, MIT Style License.
-
-var MooTools={version:"1.2.0",build:""};var Native=function(J){J=J||{};var F=J.afterImplement||function(){};var G=J.generics;G=(G!==false);var H=J.legacy;
-var E=J.initialize;var B=J.protect;var A=J.name;var C=E||H;C.constructor=Native;C.$family={name:"native"};if(H&&E){C.prototype=H.prototype;}C.prototype.constructor=C;
-if(A){var D=A.toLowerCase();C.prototype.$family={name:D};Native.typize(C,D);}var I=function(M,K,N,L){if(!B||L||!M.prototype[K]){M.prototype[K]=N;}if(G){Native.genericize(M,K,B);
-}F.call(M,K,N);return M;};C.implement=function(L,K,N){if(typeof L=="string"){return I(this,L,K,N);}for(var M in L){I(this,M,L[M],K);}return this;};C.alias=function(M,K,N){if(typeof M=="string"){M=this.prototype[M];
-if(M){I(this,K,M,N);}}else{for(var L in M){this.alias(L,M[L],K);}}return this;};return C;};Native.implement=function(D,C){for(var B=0,A=D.length;B<A;B++){D[B].implement(C);
-}};Native.genericize=function(B,C,A){if((!A||!B[C])&&typeof B.prototype[C]=="function"){B[C]=function(){var D=Array.prototype.slice.call(arguments);return B.prototype[C].apply(D.shift(),D);
-};}};Native.typize=function(A,B){if(!A.type){A.type=function(C){return($type(C)===B);};}};Native.alias=function(E,B,A,F){for(var D=0,C=E.length;D<C;D++){E[D].alias(B,A,F);
-}};(function(B){for(var A in B){Native.typize(B[A],A);}})({"boolean":Boolean,"native":Native,object:Object});(function(B){for(var A in B){new Native({name:A,initialize:B[A],protect:true});
-}})({String:String,Function:Function,Number:Number,Array:Array,RegExp:RegExp,Date:Date});(function(B,A){for(var C=A.length;C--;C){Native.genericize(B,A[C],true);
-}return arguments.callee;})(Array,["pop","push","reverse","shift","sort","splice","unshift","concat","join","slice","toString","valueOf","indexOf","lastIndexOf"])(String,["charAt","charCodeAt","concat","indexOf","lastIndexOf","match","replace","search","slice","split","substr","substring","toLowerCase","toUpperCase","valueOf"]);
-function $chk(A){return !!(A||A===0);}function $clear(A){clearTimeout(A);clearInterval(A);return null;}function $defined(A){return(A!=undefined);}function $empty(){}function $arguments(A){return function(){return arguments[A];
-};}function $lambda(A){return(typeof A=="function")?A:function(){return A;};}function $extend(C,A){for(var B in (A||{})){C[B]=A[B];}return C;}function $unlink(C){var B;
-switch($type(C)){case"object":B={};for(var E in C){B[E]=$unlink(C[E]);}break;case"hash":B=$unlink(C.getClean());break;case"array":B=[];for(var D=0,A=C.length;
-D<A;D++){B[D]=$unlink(C[D]);}break;default:return C;}return B;}function $merge(){var E={};for(var D=0,A=arguments.length;D<A;D++){var B=arguments[D];if($type(B)!="object"){continue;
-}for(var C in B){var G=B[C],F=E[C];E[C]=(F&&$type(G)=="object"&&$type(F)=="object")?$merge(F,G):$unlink(G);}}return E;}function $pick(){for(var B=0,A=arguments.length;
-B<A;B++){if(arguments[B]!=undefined){return arguments[B];}}return null;}function $random(B,A){return Math.floor(Math.random()*(A-B+1)+B);}function $splat(B){var A=$type(B);
-return(A)?((A!="array"&&A!="arguments")?[B]:B):[];}var $time=Date.now||function(){return new Date().getTime();};function $try(){for(var B=0,A=arguments.length;
-B<A;B++){try{return arguments[B]();}catch(C){}}return null;}function $type(A){if(A==undefined){return false;}if(A.$family){return(A.$family.name=="number"&&!isFinite(A))?false:A.$family.name;
-}if(A.nodeName){switch(A.nodeType){case 1:return"element";case 3:return(/\S/).test(A.nodeValue)?"textnode":"whitespace";}}else{if(typeof A.length=="number"){if(A.callee){return"arguments";
-}else{if(A.item){return"collection";}}}}return typeof A;}var Hash=new Native({name:"Hash",initialize:function(A){if($type(A)=="hash"){A=$unlink(A.getClean());
-}for(var B in A){this[B]=A[B];}return this;}});Hash.implement({getLength:function(){var B=0;for(var A in this){if(this.hasOwnProperty(A)){B++;}}return B;
-},forEach:function(B,C){for(var A in this){if(this.hasOwnProperty(A)){B.call(C,this[A],A,this);}}},getClean:function(){var B={};for(var A in this){if(this.hasOwnProperty(A)){B[A]=this[A];
-}}return B;}});Hash.alias("forEach","each");function $H(A){return new Hash(A);}Array.implement({forEach:function(C,D){for(var B=0,A=this.length;B<A;B++){C.call(D,this[B],B,this);
-}}});Array.alias("forEach","each");function $A(C){if(C.item){var D=[];for(var B=0,A=C.length;B<A;B++){D[B]=C[B];}return D;}return Array.prototype.slice.call(C);
-}function $each(C,B,D){var A=$type(C);((A=="arguments"||A=="collection"||A=="array")?Array:Hash).each(C,B,D);}var Browser=new Hash({Engine:{name:"unknown",version:""},Platform:{name:(navigator.platform.match(/mac|win|linux/i)||["other"])[0].toLowerCase()},Features:{xpath:!!(document.evaluate),air:!!(window.runtime)},Plugins:{}});
-if(window.opera){Browser.Engine={name:"presto",version:(document.getElementsByClassName)?950:925};}else{if(window.ActiveXObject){Browser.Engine={name:"trident",version:(window.XMLHttpRequest)?5:4};
-}else{if(!navigator.taintEnabled){Browser.Engine={name:"webkit",version:(Browser.Features.xpath)?420:419};}else{if(document.getBoxObjectFor!=null){Browser.Engine={name:"gecko",version:(document.getElementsByClassName)?19:18};
-}}}}Browser.Engine[Browser.Engine.name]=Browser.Engine[Browser.Engine.name+Browser.Engine.version]=true;if(window.orientation!=undefined){Browser.Platform.name="ipod";
-}Browser.Platform[Browser.Platform.name]=true;Browser.Request=function(){return $try(function(){return new XMLHttpRequest();},function(){return new ActiveXObject("MSXML2.XMLHTTP");
-});};Browser.Features.xhr=!!(Browser.Request());Browser.Plugins.Flash=(function(){var A=($try(function(){return navigator.plugins["Shockwave Flash"].description;
-},function(){return new ActiveXObject("ShockwaveFlash.ShockwaveFlash").GetVariable("$version");})||"0 r0").match(/\d+/g);return{version:parseInt(A[0]||0+"."+A[1]||0),build:parseInt(A[2]||0)};
-})();function $exec(B){if(!B){return B;}if(window.execScript){window.execScript(B);}else{var A=document.createElement("script");A.setAttribute("type","text/javascript");
-A.text=B;document.head.appendChild(A);document.head.removeChild(A);}return B;}Native.UID=1;var $uid=(Browser.Engine.trident)?function(A){return(A.uid||(A.uid=[Native.UID++]))[0];
-}:function(A){return A.uid||(A.uid=Native.UID++);};var Window=new Native({name:"Window",legacy:(Browser.Engine.trident)?null:window.Window,initialize:function(A){$uid(A);
-if(!A.Element){A.Element=$empty;if(Browser.Engine.webkit){A.document.createElement("iframe");}A.Element.prototype=(Browser.Engine.webkit)?window["[[DOMElement.prototype]]"]:{};
-}return $extend(A,Window.Prototype);},afterImplement:function(B,A){window[B]=Window.Prototype[B]=A;}});Window.Prototype={$family:{name:"window"}};new Window(window);
-var Document=new Native({name:"Document",legacy:(Browser.Engine.trident)?null:window.Document,initialize:function(A){$uid(A);A.head=A.getElementsByTagName("head")[0];
-A.html=A.getElementsByTagName("html")[0];A.window=A.defaultView||A.parentWindow;if(Browser.Engine.trident4){$try(function(){A.execCommand("BackgroundImageCache",false,true);
-});}return $extend(A,Document.Prototype);},afterImplement:function(B,A){document[B]=Document.Prototype[B]=A;}});Document.Prototype={$family:{name:"document"}};
-new Document(document);Array.implement({every:function(C,D){for(var B=0,A=this.length;B<A;B++){if(!C.call(D,this[B],B,this)){return false;}}return true;
-},filter:function(D,E){var C=[];for(var B=0,A=this.length;B<A;B++){if(D.call(E,this[B],B,this)){C.push(this[B]);}}return C;},clean:function(){return this.filter($defined);
-},indexOf:function(C,D){var A=this.length;for(var B=(D<0)?Math.max(0,A+D):D||0;B<A;B++){if(this[B]===C){return B;}}return -1;},map:function(D,E){var C=[];
-for(var B=0,A=this.length;B<A;B++){C[B]=D.call(E,this[B],B,this);}return C;},some:function(C,D){for(var B=0,A=this.length;B<A;B++){if(C.call(D,this[B],B,this)){return true;
-}}return false;},associate:function(C){var D={},B=Math.min(this.length,C.length);for(var A=0;A<B;A++){D[C[A]]=this[A];}return D;},link:function(C){var A={};
-for(var E=0,B=this.length;E<B;E++){for(var D in C){if(C[D](this[E])){A[D]=this[E];delete C[D];break;}}}return A;},contains:function(A,B){return this.indexOf(A,B)!=-1;
-},extend:function(C){for(var B=0,A=C.length;B<A;B++){this.push(C[B]);}return this;},getLast:function(){return(this.length)?this[this.length-1]:null;},getRandom:function(){return(this.length)?this[$random(0,this.length-1)]:null;
-},include:function(A){if(!this.contains(A)){this.push(A);}return this;},combine:function(C){for(var B=0,A=C.length;B<A;B++){this.include(C[B]);}return this;
-},erase:function(B){for(var A=this.length;A--;A){if(this[A]===B){this.splice(A,1);}}return this;},empty:function(){this.length=0;return this;},flatten:function(){var D=[];
-for(var B=0,A=this.length;B<A;B++){var C=$type(this[B]);if(!C){continue;}D=D.concat((C=="array"||C=="collection"||C=="arguments")?Array.flatten(this[B]):this[B]);
-}return D;},hexToRgb:function(B){if(this.length!=3){return null;}var A=this.map(function(C){if(C.length==1){C+=C;}return C.toInt(16);});return(B)?A:"rgb("+A+")";
-},rgbToHex:function(D){if(this.length<3){return null;}if(this.length==4&&this[3]==0&&!D){return"transparent";}var B=[];for(var A=0;A<3;A++){var C=(this[A]-0).toString(16);
-B.push((C.length==1)?"0"+C:C);}return(D)?B:"#"+B.join("");}});Function.implement({extend:function(A){for(var B in A){this[B]=A[B];}return this;},create:function(B){var A=this;
-B=B||{};return function(D){var C=B.arguments;C=(C!=undefined)?$splat(C):Array.slice(arguments,(B.event)?1:0);if(B.event){C=[D||window.event].extend(C);
-}var E=function(){return A.apply(B.bind||null,C);};if(B.delay){return setTimeout(E,B.delay);}if(B.periodical){return setInterval(E,B.periodical);}if(B.attempt){return $try(E);
-}return E();};},pass:function(A,B){return this.create({arguments:A,bind:B});},attempt:function(A,B){return this.create({arguments:A,bind:B,attempt:true})();
-},bind:function(B,A){return this.create({bind:B,arguments:A});},bindWithEvent:function(B,A){return this.create({bind:B,event:true,arguments:A});},delay:function(B,C,A){return this.create({delay:B,bind:C,arguments:A})();
-},periodical:function(A,C,B){return this.create({periodical:A,bind:C,arguments:B})();},run:function(A,B){return this.apply(B,$splat(A));}});Number.implement({limit:function(B,A){return Math.min(A,Math.max(B,this));
-},round:function(A){A=Math.pow(10,A||0);return Math.round(this*A)/A;},times:function(B,C){for(var A=0;A<this;A++){B.call(C,A,this);}},toFloat:function(){return parseFloat(this);
-},toInt:function(A){return parseInt(this,A||10);}});Number.alias("times","each");(function(B){var A={};B.each(function(C){if(!Number[C]){A[C]=function(){return Math[C].apply(null,[this].concat($A(arguments)));
-};}});Number.implement(A);})(["abs","acos","asin","atan","atan2","ceil","cos","exp","floor","log","max","min","pow","sin","sqrt","tan"]);String.implement({test:function(A,B){return((typeof A=="string")?new RegExp(A,B):A).test(this);
-},contains:function(A,B){return(B)?(B+this+B).indexOf(B+A+B)>-1:this.indexOf(A)>-1;},trim:function(){return this.replace(/^\s+|\s+$/g,"");},clean:function(){return this.replace(/\s+/g," ").trim();
-},camelCase:function(){return this.replace(/-\D/g,function(A){return A.charAt(1).toUpperCase();});},hyphenate:function(){return this.replace(/[A-Z]/g,function(A){return("-"+A.charAt(0).toLowerCase());
-});},capitalize:function(){return this.replace(/\b[a-z]/g,function(A){return A.toUpperCase();});},escapeRegExp:function(){return this.replace(/([-.*+?^${}()|[\]\/\\])/g,"\\$1");
-},toInt:function(A){return parseInt(this,A||10);},toFloat:function(){return parseFloat(this);},hexToRgb:function(B){var A=this.match(/^#?(\w{1,2})(\w{1,2})(\w{1,2})$/);
-return(A)?A.slice(1).hexToRgb(B):null;},rgbToHex:function(B){var A=this.match(/\d{1,3}/g);return(A)?A.rgbToHex(B):null;},stripScripts:function(B){var A="";
-var C=this.replace(/<script[^>]*>([\s\S]*?)<\/script>/gi,function(){A+=arguments[1]+"\n";return"";});if(B===true){$exec(A);}else{if($type(B)=="function"){B(A,C);
-}}return C;},substitute:function(A,B){return this.replace(B||(/\\?\{([^}]+)\}/g),function(D,C){if(D.charAt(0)=="\\"){return D.slice(1);}return(A[C]!=undefined)?A[C]:"";
-});}});Hash.implement({has:Object.prototype.hasOwnProperty,keyOf:function(B){for(var A in this){if(this.hasOwnProperty(A)&&this[A]===B){return A;}}return null;
-},hasValue:function(A){return(Hash.keyOf(this,A)!==null);},extend:function(A){Hash.each(A,function(C,B){Hash.set(this,B,C);},this);return this;},combine:function(A){Hash.each(A,function(C,B){Hash.include(this,B,C);
-},this);return this;},erase:function(A){if(this.hasOwnProperty(A)){delete this[A];}return this;},get:function(A){return(this.hasOwnProperty(A))?this[A]:null;
-},set:function(A,B){if(!this[A]||this.hasOwnProperty(A)){this[A]=B;}return this;},empty:function(){Hash.each(this,function(B,A){delete this[A];},this);
-return this;},include:function(B,C){var A=this[B];if(A==undefined){this[B]=C;}return this;},map:function(B,C){var A=new Hash;Hash.each(this,function(E,D){A.set(D,B.call(C,E,D,this));
-},this);return A;},filter:function(B,C){var A=new Hash;Hash.each(this,function(E,D){if(B.call(C,E,D,this)){A.set(D,E);}},this);return A;},every:function(B,C){for(var A in this){if(this.hasOwnProperty(A)&&!B.call(C,this[A],A)){return false;
-}}return true;},some:function(B,C){for(var A in this){if(this.hasOwnProperty(A)&&B.call(C,this[A],A)){return true;}}return false;},getKeys:function(){var A=[];
-Hash.each(this,function(C,B){A.push(B);});return A;},getValues:function(){var A=[];Hash.each(this,function(B){A.push(B);});return A;},toQueryString:function(A){var B=[];
-Hash.each(this,function(F,E){if(A){E=A+"["+E+"]";}var D;switch($type(F)){case"object":D=Hash.toQueryString(F,E);break;case"array":var C={};F.each(function(H,G){C[G]=H;
-});D=Hash.toQueryString(C,E);break;default:D=E+"="+encodeURIComponent(F);}if(F!=undefined){B.push(D);}});return B.join("&");}});Hash.alias({keyOf:"indexOf",hasValue:"contains"});
-var Event=new Native({name:"Event",initialize:function(A,F){F=F||window;var K=F.document;A=A||F.event;if(A.$extended){return A;}this.$extended=true;var J=A.type;
-var G=A.target||A.srcElement;while(G&&G.nodeType==3){G=G.parentNode;}if(J.test(/key/)){var B=A.which||A.keyCode;var M=Event.Keys.keyOf(B);if(J=="keydown"){var D=B-111;
-if(D>0&&D<13){M="f"+D;}}M=M||String.fromCharCode(B).toLowerCase();}else{if(J.match(/(click|mouse|menu)/i)){K=(!K.compatMode||K.compatMode=="CSS1Compat")?K.html:K.body;
-var I={x:A.pageX||A.clientX+K.scrollLeft,y:A.pageY||A.clientY+K.scrollTop};var C={x:(A.pageX)?A.pageX-F.pageXOffset:A.clientX,y:(A.pageY)?A.pageY-F.pageYOffset:A.clientY};
-if(J.match(/DOMMouseScroll|mousewheel/)){var H=(A.wheelDelta)?A.wheelDelta/120:-(A.detail||0)/3;}var E=(A.which==3)||(A.button==2);var L=null;if(J.match(/over|out/)){switch(J){case"mouseover":L=A.relatedTarget||A.fromElement;
-break;case"mouseout":L=A.relatedTarget||A.toElement;}if(!(function(){while(L&&L.nodeType==3){L=L.parentNode;}return true;}).create({attempt:Browser.Engine.gecko})()){L=false;
-}}}}return $extend(this,{event:A,type:J,page:I,client:C,rightClick:E,wheel:H,relatedTarget:L,target:G,code:B,key:M,shift:A.shiftKey,control:A.ctrlKey,alt:A.altKey,meta:A.metaKey});
-}});Event.Keys=new Hash({enter:13,up:38,down:40,left:37,right:39,esc:27,space:32,backspace:8,tab:9,"delete":46});Event.implement({stop:function(){return this.stopPropagation().preventDefault();
-},stopPropagation:function(){if(this.event.stopPropagation){this.event.stopPropagation();}else{this.event.cancelBubble=true;}return this;},preventDefault:function(){if(this.event.preventDefault){this.event.preventDefault();
-}else{this.event.returnValue=false;}return this;}});var Class=new Native({name:"Class",initialize:function(B){B=B||{};var A=function(E){for(var D in this){this[D]=$unlink(this[D]);
-}for(var F in Class.Mutators){if(!this[F]){continue;}Class.Mutators[F](this,this[F]);delete this[F];}this.constructor=A;if(E===$empty){return this;}var C=(this.initialize)?this.initialize.apply(this,arguments):this;
-if(this.options&&this.options.initialize){this.options.initialize.call(this);}return C;};$extend(A,this);A.constructor=Class;A.prototype=B;return A;}});
-Class.implement({implement:function(){Class.Mutators.Implements(this.prototype,Array.slice(arguments));return this;}});Class.Mutators={Implements:function(A,B){$splat(B).each(function(C){$extend(A,($type(C)=="class")?new C($empty):C);
-});},Extends:function(self,klass){var instance=new klass($empty);delete instance.parent;delete instance.parentOf;for(var key in instance){var current=self[key],previous=instance[key];
-if(current==undefined){self[key]=previous;continue;}var ctype=$type(current),ptype=$type(previous);if(ctype!=ptype){continue;}switch(ctype){case"function":if(!arguments.callee.caller){self[key]=eval("("+String(current).replace(/\bthis\.parent\(\s*(\))?/g,function(full,close){return"arguments.callee._parent_.call(this"+(close||", ");
-})+")");}self[key]._parent_=previous;break;case"object":self[key]=$merge(previous,current);}}self.parent=function(){return arguments.callee.caller._parent_.apply(this,arguments);
-};self.parentOf=function(descendant){return descendant._parent_.apply(this,Array.slice(arguments,1));};}};var Chain=new Class({chain:function(){this.$chain=(this.$chain||[]).extend(arguments);
-return this;},callChain:function(){return(this.$chain&&this.$chain.length)?this.$chain.shift().apply(this,arguments):false;},clearChain:function(){if(this.$chain){this.$chain.empty();
-}return this;}});var Events=new Class({addEvent:function(C,B,A){C=Events.removeOn(C);if(B!=$empty){this.$events=this.$events||{};this.$events[C]=this.$events[C]||[];
-this.$events[C].include(B);if(A){B.internal=true;}}return this;},addEvents:function(A){for(var B in A){this.addEvent(B,A[B]);}return this;},fireEvent:function(C,B,A){C=Events.removeOn(C);
-if(!this.$events||!this.$events[C]){return this;}this.$events[C].each(function(D){D.create({bind:this,delay:A,"arguments":B})();},this);return this;},removeEvent:function(B,A){B=Events.removeOn(B);
-if(!this.$events||!this.$events[B]){return this;}if(!A.internal){this.$events[B].erase(A);}return this;},removeEvents:function(C){for(var D in this.$events){if(C&&C!=D){continue;
-}var B=this.$events[D];for(var A=B.length;A--;A){this.removeEvent(D,B[A]);}}return this;}});Events.removeOn=function(A){return A.replace(/^on([A-Z])/,function(B,C){return C.toLowerCase();
-});};var Options=new Class({setOptions:function(){this.options=$merge.run([this.options].extend(arguments));if(!this.addEvent){return this;}for(var A in this.options){if($type(this.options[A])!="function"||!(/^on[A-Z]/).test(A)){continue;
-}this.addEvent(A,this.options[A]);delete this.options[A];}return this;}});Document.implement({newElement:function(A,B){if(Browser.Engine.trident&&B){["name","type","checked"].each(function(C){if(!B[C]){return ;
-}A+=" "+C+'="'+B[C]+'"';if(C!="checked"){delete B[C];}});A="<"+A+">";}return $.element(this.createElement(A)).set(B);},newTextNode:function(A){return this.createTextNode(A);
-},getDocument:function(){return this;},getWindow:function(){return this.defaultView||this.parentWindow;},purge:function(){var C=this.getElementsByTagName("*");
-for(var B=0,A=C.length;B<A;B++){Browser.freeMem(C[B]);}}});var Element=new Native({name:"Element",legacy:window.Element,initialize:function(A,B){var C=Element.Constructors.get(A);
-if(C){return C(B);}if(typeof A=="string"){return document.newElement(A,B);}return $(A).set(B);},afterImplement:function(A,B){if(!Array[A]){Elements.implement(A,Elements.multi(A));
-}Element.Prototype[A]=B;}});Element.Prototype={$family:{name:"element"}};Element.Constructors=new Hash;var IFrame=new Native({name:"IFrame",generics:false,initialize:function(){var E=Array.link(arguments,{properties:Object.type,iframe:$defined});
-var C=E.properties||{};var B=$(E.iframe)||false;var D=C.onload||$empty;delete C.onload;C.id=C.name=$pick(C.id,C.name,B.id,B.name,"IFrame_"+$time());B=new Element(B||"iframe",C);
-var A=function(){var F=$try(function(){return B.contentWindow.location.host;});if(F&&F==window.location.host){var H=new Window(B.contentWindow);var G=new Document(B.contentWindow.document);
-$extend(H.Element.prototype,Element.Prototype);}D.call(B.contentWindow,B.contentWindow.document);};(!window.frames[C.id])?B.addListener("load",A):A();return B;
-}});var Elements=new Native({initialize:function(F,B){B=$extend({ddup:true,cash:true},B);F=F||[];if(B.ddup||B.cash){var G={},E=[];for(var C=0,A=F.length;
-C<A;C++){var D=$.element(F[C],!B.cash);if(B.ddup){if(G[D.uid]){continue;}G[D.uid]=true;}E.push(D);}F=E;}return(B.cash)?$extend(F,this):F;}});Elements.implement({filter:function(A,B){if(!A){return this;
-}return new Elements(Array.filter(this,(typeof A=="string")?function(C){return C.match(A);}:A,B));}});Elements.multi=function(A){return function(){var B=[];
-var F=true;for(var D=0,C=this.length;D<C;D++){var E=this[D][A].apply(this[D],arguments);B.push(E);if(F){F=($type(E)=="element");}}return(F)?new Elements(B):B;
-};};Window.implement({$:function(B,C){if(B&&B.$family&&B.uid){return B;}var A=$type(B);return($[A])?$[A](B,C,this.document):null;},$$:function(A){if(arguments.length==1&&typeof A=="string"){return this.document.getElements(A);
-}var F=[];var C=Array.flatten(arguments);for(var D=0,B=C.length;D<B;D++){var E=C[D];switch($type(E)){case"element":E=[E];break;case"string":E=this.document.getElements(E,true);
-break;default:E=false;}if(E){F.extend(E);}}return new Elements(F);},getDocument:function(){return this.document;},getWindow:function(){return this;}});
-$.string=function(C,B,A){C=A.getElementById(C);return(C)?$.element(C,B):null;};$.element=function(A,D){$uid(A);if(!D&&!A.$family&&!(/^object|embed$/i).test(A.tagName)){var B=Element.Prototype;
-for(var C in B){A[C]=B[C];}}return A;};$.object=function(B,C,A){if(B.toElement){return $.element(B.toElement(A),C);}return null;};$.textnode=$.whitespace=$.window=$.document=$arguments(0);
-Native.implement([Element,Document],{getElement:function(A,B){return $(this.getElements(A,true)[0]||null,B);},getElements:function(A,D){A=A.split(",");
-var C=[];var B=(A.length>1);A.each(function(E){var F=this.getElementsByTagName(E.trim());(B)?C.extend(F):C=F;},this);return new Elements(C,{ddup:B,cash:!D});
-}});Element.Storage={get:function(A){return(this[A]||(this[A]={}));}};Element.Inserters=new Hash({before:function(B,A){if(A.parentNode){A.parentNode.insertBefore(B,A);
-}},after:function(B,A){if(!A.parentNode){return ;}var C=A.nextSibling;(C)?A.parentNode.insertBefore(B,C):A.parentNode.appendChild(B);},bottom:function(B,A){A.appendChild(B);
-},top:function(B,A){var C=A.firstChild;(C)?A.insertBefore(B,C):A.appendChild(B);}});Element.Inserters.inside=Element.Inserters.bottom;Element.Inserters.each(function(C,B){var A=B.capitalize();
-Element.implement("inject"+A,function(D){C(this,$(D,true));return this;});Element.implement("grab"+A,function(D){C($(D,true),this);return this;});});Element.implement({getDocument:function(){return this.ownerDocument;
-},getWindow:function(){return this.ownerDocument.getWindow();},getElementById:function(D,C){var B=this.ownerDocument.getElementById(D);if(!B){return null;
-}for(var A=B.parentNode;A!=this;A=A.parentNode){if(!A){return null;}}return $.element(B,C);},set:function(D,B){switch($type(D)){case"object":for(var C in D){this.set(C,D[C]);
-}break;case"string":var A=Element.Properties.get(D);(A&&A.set)?A.set.apply(this,Array.slice(arguments,1)):this.setProperty(D,B);}return this;},get:function(B){var A=Element.Properties.get(B);
-return(A&&A.get)?A.get.apply(this,Array.slice(arguments,1)):this.getProperty(B);},erase:function(B){var A=Element.Properties.get(B);(A&&A.erase)?A.erase.apply(this,Array.slice(arguments,1)):this.removeProperty(B);
-return this;},match:function(A){return(!A||Element.get(this,"tag")==A);},inject:function(B,A){Element.Inserters.get(A||"bottom")(this,$(B,true));return this;
-},wraps:function(B,A){B=$(B,true);return this.replaces(B).grab(B,A);},grab:function(B,A){Element.Inserters.get(A||"bottom")($(B,true),this);return this;
-},appendText:function(B,A){return this.grab(this.getDocument().newTextNode(B),A);},adopt:function(){Array.flatten(arguments).each(function(A){A=$(A,true);
-if(A){this.appendChild(A);}},this);return this;},dispose:function(){return(this.parentNode)?this.parentNode.removeChild(this):this;},clone:function(D,C){switch($type(this)){case"element":var H={};
-for(var G=0,E=this.attributes.length;G<E;G++){var B=this.attributes[G],L=B.nodeName.toLowerCase();if(Browser.Engine.trident&&(/input/i).test(this.tagName)&&(/width|height/).test(L)){continue;
-}var K=(L=="style"&&this.style)?this.style.cssText:B.nodeValue;if(!$chk(K)||L=="uid"||(L=="id"&&!C)){continue;}if(K!="inherit"&&["string","number"].contains($type(K))){H[L]=K;
-}}var J=new Element(this.nodeName.toLowerCase(),H);if(D!==false){for(var I=0,F=this.childNodes.length;I<F;I++){var A=Element.clone(this.childNodes[I],true,C);
-if(A){J.grab(A);}}}return J;case"textnode":return document.newTextNode(this.nodeValue);}return null;},replaces:function(A){A=$(A,true);A.parentNode.replaceChild(this,A);
-return this;},hasClass:function(A){return this.className.contains(A," ");},addClass:function(A){if(!this.hasClass(A)){this.className=(this.className+" "+A).clean();
-}return this;},removeClass:function(A){this.className=this.className.replace(new RegExp("(^|\\s)"+A+"(?:\\s|$)"),"$1").clean();return this;},toggleClass:function(A){return this.hasClass(A)?this.removeClass(A):this.addClass(A);
-},getComputedStyle:function(B){if(this.currentStyle){return this.currentStyle[B.camelCase()];}var A=this.getWindow().getComputedStyle(this,null);return(A)?A.getPropertyValue([B.hyphenate()]):null;
-},empty:function(){$A(this.childNodes).each(function(A){Browser.freeMem(A);Element.empty(A);Element.dispose(A);},this);return this;},destroy:function(){Browser.freeMem(this.empty().dispose());
-return null;},getSelected:function(){return new Elements($A(this.options).filter(function(A){return A.selected;}));},toQueryString:function(){var A=[];
-this.getElements("input, select, textarea").each(function(B){if(!B.name||B.disabled){return ;}var C=(B.tagName.toLowerCase()=="select")?Element.getSelected(B).map(function(D){return D.value;
-}):((B.type=="radio"||B.type=="checkbox")&&!B.checked)?null:B.value;$splat(C).each(function(D){if(D){A.push(B.name+"="+encodeURIComponent(D));}});});return A.join("&");
-},getProperty:function(C){var B=Element.Attributes,A=B.Props[C];var D=(A)?this[A]:this.getAttribute(C,2);return(B.Bools[C])?!!D:(A)?D:D||null;},getProperties:function(){var A=$A(arguments);
-return A.map(function(B){return this.getProperty(B);},this).associate(A);},setProperty:function(D,E){var C=Element.Attributes,B=C.Props[D],A=$defined(E);
-if(B&&C.Bools[D]){E=(E||!A)?true:false;}else{if(!A){return this.removeProperty(D);}}(B)?this[B]=E:this.setAttribute(D,E);return this;},setProperties:function(A){for(var B in A){this.setProperty(B,A[B]);
-}return this;},removeProperty:function(D){var C=Element.Attributes,B=C.Props[D],A=(B&&C.Bools[D]);(B)?this[B]=(A)?false:"":this.removeAttribute(D);return this;
-},removeProperties:function(){Array.each(arguments,this.removeProperty,this);return this;}});(function(){var A=function(D,B,I,C,F,H){var E=D[I||B];var G=[];
-while(E){if(E.nodeType==1&&(!C||Element.match(E,C))){G.push(E);if(!F){break;}}E=E[B];}return(F)?new Elements(G,{ddup:false,cash:!H}):$(G[0],H);};Element.implement({getPrevious:function(B,C){return A(this,"previousSibling",null,B,false,C);
-},getAllPrevious:function(B,C){return A(this,"previousSibling",null,B,true,C);},getNext:function(B,C){return A(this,"nextSibling",null,B,false,C);},getAllNext:function(B,C){return A(this,"nextSibling",null,B,true,C);
-},getFirst:function(B,C){return A(this,"nextSibling","firstChild",B,false,C);},getLast:function(B,C){return A(this,"previousSibling","lastChild",B,false,C);
-},getParent:function(B,C){return A(this,"parentNode",null,B,false,C);},getParents:function(B,C){return A(this,"parentNode",null,B,true,C);},getChildren:function(B,C){return A(this,"nextSibling","firstChild",B,true,C);
-},hasChild:function(B){B=$(B,true);return(!!B&&$A(this.getElementsByTagName(B.tagName)).contains(B));}});})();Element.Properties=new Hash;Element.Properties.style={set:function(A){this.style.cssText=A;
-},get:function(){return this.style.cssText;},erase:function(){this.style.cssText="";}};Element.Properties.tag={get:function(){return this.tagName.toLowerCase();
-}};Element.Properties.href={get:function(){return(!this.href)?null:this.href.replace(new RegExp("^"+document.location.protocol+"//"+document.location.host),"");
-}};Element.Properties.html={set:function(){return this.innerHTML=Array.flatten(arguments).join("");}};Native.implement([Element,Window,Document],{addListener:function(B,A){if(this.addEventListener){this.addEventListener(B,A,false);
-}else{this.attachEvent("on"+B,A);}return this;},removeListener:function(B,A){if(this.removeEventListener){this.removeEventListener(B,A,false);}else{this.detachEvent("on"+B,A);
-}return this;},retrieve:function(B,A){var D=Element.Storage.get(this.uid);var C=D[B];if($defined(A)&&!$defined(C)){C=D[B]=A;}return $pick(C);},store:function(B,A){var C=Element.Storage.get(this.uid);
-C[B]=A;return this;},eliminate:function(A){var B=Element.Storage.get(this.uid);delete B[A];return this;}});Element.Attributes=new Hash({Props:{html:"innerHTML","class":"className","for":"htmlFor",text:(Browser.Engine.trident)?"innerText":"textContent"},Bools:["compact","nowrap","ismap","declare","noshade","checked","disabled","readonly","multiple","selected","noresize","defer"],Camels:["value","accessKey","cellPadding","cellSpacing","colSpan","frameBorder","maxLength","readOnly","rowSpan","tabIndex","useMap"]});
-Browser.freeMem=function(A){if(!A){return ;}if(Browser.Engine.trident&&(/object/i).test(A.tagName)){for(var B in A){if(typeof A[B]=="function"){A[B]=$empty;
-}}Element.dispose(A);}if(A.uid&&A.removeEvents){A.removeEvents();}};(function(B){var C=B.Bools,A=B.Camels;B.Bools=C=C.associate(C);Hash.extend(Hash.combine(B.Props,C),A.associate(A.map(function(D){return D.toLowerCase();
-})));B.erase("Camels");})(Element.Attributes);window.addListener("unload",function(){window.removeListener("unload",arguments.callee);document.purge();
-if(Browser.Engine.trident){CollectGarbage();}});Element.Properties.events={set:function(A){this.addEvents(A);}};Native.implement([Element,Window,Document],{addEvent:function(E,G){var H=this.retrieve("events",{});
-H[E]=H[E]||{keys:[],values:[]};if(H[E].keys.contains(G)){return this;}H[E].keys.push(G);var F=E,A=Element.Events.get(E),C=G,I=this;if(A){if(A.onAdd){A.onAdd.call(this,G);
-}if(A.condition){C=function(J){if(A.condition.call(this,J)){return G.call(this,J);}return false;};}F=A.base||F;}var D=function(){return G.call(I);};var B=Element.NativeEvents[F]||0;
-if(B){if(B==2){D=function(J){J=new Event(J,I.getWindow());if(C.call(I,J)===false){J.stop();}};}this.addListener(F,D);}H[E].values.push(D);return this;},removeEvent:function(D,C){var B=this.retrieve("events");
-if(!B||!B[D]){return this;}var G=B[D].keys.indexOf(C);if(G==-1){return this;}var A=B[D].keys.splice(G,1)[0];var F=B[D].values.splice(G,1)[0];var E=Element.Events.get(D);
-if(E){if(E.onRemove){E.onRemove.call(this,C);}D=E.base||D;}return(Element.NativeEvents[D])?this.removeListener(D,F):this;},addEvents:function(A){for(var B in A){this.addEvent(B,A[B]);
-}return this;},removeEvents:function(B){var A=this.retrieve("events");if(!A){return this;}if(!B){for(var C in A){this.removeEvents(C);}A=null;}else{if(A[B]){while(A[B].keys[0]){this.removeEvent(B,A[B].keys[0]);
-}A[B]=null;}}return this;},fireEvent:function(D,B,A){var C=this.retrieve("events");if(!C||!C[D]){return this;}C[D].keys.each(function(E){E.create({bind:this,delay:A,"arguments":B})();
-},this);return this;},cloneEvents:function(D,A){D=$(D);var C=D.retrieve("events");if(!C){return this;}if(!A){for(var B in C){this.cloneEvents(D,B);}}else{if(C[A]){C[A].keys.each(function(E){this.addEvent(A,E);
-},this);}}return this;}});Element.NativeEvents={click:2,dblclick:2,mouseup:2,mousedown:2,contextmenu:2,mousewheel:2,DOMMouseScroll:2,mouseover:2,mouseout:2,mousemove:2,selectstart:2,selectend:2,keydown:2,keypress:2,keyup:2,focus:2,blur:2,change:2,reset:2,select:2,submit:2,load:1,unload:1,beforeunload:2,resize:1,move:1,DOMContentLoaded:1,readystatechange:1,error:1,abort:1,scroll:1};
-(function(){var A=function(B){var C=B.relatedTarget;if(C==undefined){return true;}if(C===false){return false;}return($type(this)!="document"&&C!=this&&C.prefix!="xul"&&!this.hasChild(C));
-};Element.Events=new Hash({mouseenter:{base:"mouseover",condition:A},mouseleave:{base:"mouseout",condition:A},mousewheel:{base:(Browser.Engine.gecko)?"DOMMouseScroll":"mousewheel"}});
-})();Element.Properties.styles={set:function(A){this.setStyles(A);}};Element.Properties.opacity={set:function(A,B){if(!B){if(A==0){if(this.style.visibility!="hidden"){this.style.visibility="hidden";
-}}else{if(this.style.visibility!="visible"){this.style.visibility="visible";}}}if(!this.currentStyle||!this.currentStyle.hasLayout){this.style.zoom=1;}if(Browser.Engine.trident){this.style.filter=(A==1)?"":"alpha(opacity="+A*100+")";
-}this.style.opacity=A;this.store("opacity",A);},get:function(){return this.retrieve("opacity",1);}};Element.implement({setOpacity:function(A){return this.set("opacity",A,true);
-},getOpacity:function(){return this.get("opacity");},setStyle:function(B,A){switch(B){case"opacity":return this.set("opacity",parseFloat(A));case"float":B=(Browser.Engine.trident)?"styleFloat":"cssFloat";
-}B=B.camelCase();if($type(A)!="string"){var C=(Element.Styles.get(B)||"@").split(" ");A=$splat(A).map(function(E,D){if(!C[D]){return"";}return($type(E)=="number")?C[D].replace("@",Math.round(E)):E;
-}).join(" ");}else{if(A==String(Number(A))){A=Math.round(A);}}this.style[B]=A;return this;},getStyle:function(G){switch(G){case"opacity":return this.get("opacity");
-case"float":G=(Browser.Engine.trident)?"styleFloat":"cssFloat";}G=G.camelCase();var A=this.style[G];if(!$chk(A)){A=[];for(var F in Element.ShortStyles){if(G!=F){continue;
-}for(var E in Element.ShortStyles[F]){A.push(this.getStyle(E));}return A.join(" ");}A=this.getComputedStyle(G);}if(A){A=String(A);var C=A.match(/rgba?\([\d\s,]+\)/);
-if(C){A=A.replace(C[0],C[0].rgbToHex());}}if(Browser.Engine.presto||(Browser.Engine.trident&&!$chk(parseInt(A)))){if(G.test(/^(height|width)$/)){var B=(G=="width")?["left","right"]:["top","bottom"],D=0;
-B.each(function(H){D+=this.getStyle("border-"+H+"-width").toInt()+this.getStyle("padding-"+H).toInt();},this);return this["offset"+G.capitalize()]-D+"px";
-}if(Browser.Engine.presto&&String(A).test("px")){return A;}if(G.test(/(border(.+)Width|margin|padding)/)){return"0px";}}return A;},setStyles:function(B){for(var A in B){this.setStyle(A,B[A]);
-}return this;},getStyles:function(){var A={};Array.each(arguments,function(B){A[B]=this.getStyle(B);},this);return A;}});Element.Styles=new Hash({left:"@px",top:"@px",bottom:"@px",right:"@px",width:"@px",height:"@px",maxWidth:"@px",maxHeight:"@px",minWidth:"@px",minHeight:"@px",backgroundColor:"rgb(@, @, @)",backgroundPosition:"@px @px",color:"rgb(@, @, @)",fontSize:"@px",letterSpacing:"@px",lineHeight:"@px",clip:"rect(@px @px @px @px)",margin:"@px @px @px @px",padding:"@px @px @px @px",border:"@px @ rgb(@, @, @) @px @ rgb(@, @, @) @px @ rgb(@, @, @)",borderWidth:"@px @px @px @px",borderStyle:"@ @ @ @",borderColor:"rgb(@, @, @) rgb(@, @, @) rgb(@, @, @) rgb(@, @, @)",zIndex:"@",zoom:"@",fontWeight:"@",textIndent:"@px",opacity:"@"});
-Element.ShortStyles={margin:{},padding:{},border:{},borderWidth:{},borderStyle:{},borderColor:{}};["Top","Right","Bottom","Left"].each(function(G){var F=Element.ShortStyles;
-var B=Element.Styles;["margin","padding"].each(function(H){var I=H+G;F[H][I]=B[I]="@px";});var E="border"+G;F.border[E]=B[E]="@px @ rgb(@, @, @)";var D=E+"Width",A=E+"Style",C=E+"Color";
-F[E]={};F.borderWidth[D]=F[E][D]=B[D]="@px";F.borderStyle[A]=F[E][A]=B[A]="@";F.borderColor[C]=F[E][C]=B[C]="rgb(@, @, @)";});(function(){Element.implement({scrollTo:function(H,I){if(B(this)){this.getWindow().scrollTo(H,I);
-}else{this.scrollLeft=H;this.scrollTop=I;}return this;},getSize:function(){if(B(this)){return this.getWindow().getSize();}return{x:this.offsetWidth,y:this.offsetHeight};
-},getScrollSize:function(){if(B(this)){return this.getWindow().getScrollSize();}return{x:this.scrollWidth,y:this.scrollHeight};},getScroll:function(){if(B(this)){return this.getWindow().getScroll();
-}return{x:this.scrollLeft,y:this.scrollTop};},getScrolls:function(){var I=this,H={x:0,y:0};while(I&&!B(I)){H.x+=I.scrollLeft;H.y+=I.scrollTop;I=I.parentNode;
-}return H;},getOffsetParent:function(){var H=this;if(B(H)){return null;}if(!Browser.Engine.trident){return H.offsetParent;}while((H=H.parentNode)&&!B(H)){if(D(H,"position")!="static"){return H;
-}}return null;},getOffsets:function(){var I=this,H={x:0,y:0};if(B(this)){return H;}while(I&&!B(I)){H.x+=I.offsetLeft;H.y+=I.offsetTop;if(Browser.Engine.gecko){if(!F(I)){H.x+=C(I);
-H.y+=G(I);}var J=I.parentNode;if(J&&D(J,"overflow")!="visible"){H.x+=C(J);H.y+=G(J);}}else{if(I!=this&&(Browser.Engine.trident||Browser.Engine.webkit)){H.x+=C(I);
-H.y+=G(I);}}I=I.offsetParent;if(Browser.Engine.trident){while(I&&!I.currentStyle.hasLayout){I=I.offsetParent;}}}if(Browser.Engine.gecko&&!F(this)){H.x-=C(this);
-H.y-=G(this);}return H;},getPosition:function(K){if(B(this)){return{x:0,y:0};}var L=this.getOffsets(),I=this.getScrolls();var H={x:L.x-I.x,y:L.y-I.y};var J=(K&&(K=$(K)))?K.getPosition():{x:0,y:0};
-return{x:H.x-J.x,y:H.y-J.y};},getCoordinates:function(J){if(B(this)){return this.getWindow().getCoordinates();}var H=this.getPosition(J),I=this.getSize();
-var K={left:H.x,top:H.y,width:I.x,height:I.y};K.right=K.left+K.width;K.bottom=K.top+K.height;return K;},computePosition:function(H){return{left:H.x-E(this,"margin-left"),top:H.y-E(this,"margin-top")};
-},position:function(H){return this.setStyles(this.computePosition(H));}});Native.implement([Document,Window],{getSize:function(){var I=this.getWindow();
-if(Browser.Engine.presto||Browser.Engine.webkit){return{x:I.innerWidth,y:I.innerHeight};}var H=A(this);return{x:H.clientWidth,y:H.clientHeight};},getScroll:function(){var I=this.getWindow();
-var H=A(this);return{x:I.pageXOffset||H.scrollLeft,y:I.pageYOffset||H.scrollTop};},getScrollSize:function(){var I=A(this);var H=this.getSize();return{x:Math.max(I.scrollWidth,H.x),y:Math.max(I.scrollHeight,H.y)};
-},getPosition:function(){return{x:0,y:0};},getCoordinates:function(){var H=this.getSize();return{top:0,left:0,bottom:H.y,right:H.x,height:H.y,width:H.x};
-}});var D=Element.getComputedStyle;function E(H,I){return D(H,I).toInt()||0;}function F(H){return D(H,"-moz-box-sizing")=="border-box";}function G(H){return E(H,"border-top-width");
-}function C(H){return E(H,"border-left-width");}function B(H){return(/^(?:body|html)$/i).test(H.tagName);}function A(H){var I=H.getDocument();return(!I.compatMode||I.compatMode=="CSS1Compat")?I.html:I.body;
-}})();Native.implement([Window,Document,Element],{getHeight:function(){return this.getSize().y;},getWidth:function(){return this.getSize().x;},getScrollTop:function(){return this.getScroll().y;
-},getScrollLeft:function(){return this.getScroll().x;},getScrollHeight:function(){return this.getScrollSize().y;},getScrollWidth:function(){return this.getScrollSize().x;
-},getTop:function(){return this.getPosition().y;},getLeft:function(){return this.getPosition().x;}});Native.implement([Document,Element],{getElements:function(H,G){H=H.split(",");
-var C,E={};for(var D=0,B=H.length;D<B;D++){var A=H[D],F=Selectors.Utils.search(this,A,E);if(D!=0&&F.item){F=$A(F);}C=(D==0)?F:(C.item)?$A(C).concat(F):C.concat(F);
-}return new Elements(C,{ddup:(H.length>1),cash:!G});}});Element.implement({match:function(B){if(!B){return true;}var D=Selectors.Utils.parseTagAndID(B);
-var A=D[0],E=D[1];if(!Selectors.Filters.byID(this,E)||!Selectors.Filters.byTag(this,A)){return false;}var C=Selectors.Utils.parseSelector(B);return(C)?Selectors.Utils.filter(this,C,{}):true;
-}});var Selectors={Cache:{nth:{},parsed:{}}};Selectors.RegExps={id:(/#([\w-]+)/),tag:(/^(\w+|\*)/),quick:(/^(\w+|\*)$/),splitter:(/\s*([+>~\s])\s*([a-zA-Z#.*:\[])/g),combined:(/\.([\w-]+)|\[(\w+)(?:([!*^$~|]?=)["']?(.*?)["']?)?\]|:([\w-]+)(?:\(["']?(.*?)?["']?\)|$)/g)};
-Selectors.Utils={chk:function(B,C){if(!C){return true;}var A=$uid(B);if(!C[A]){return C[A]=true;}return false;},parseNthArgument:function(F){if(Selectors.Cache.nth[F]){return Selectors.Cache.nth[F];
-}var C=F.match(/^([+-]?\d*)?([a-z]+)?([+-]?\d*)?$/);if(!C){return false;}var E=parseInt(C[1]);var B=(E||E===0)?E:1;var D=C[2]||false;var A=parseInt(C[3])||0;
-if(B!=0){A--;while(A<1){A+=B;}while(A>=B){A-=B;}}else{B=A;D="index";}switch(D){case"n":C={a:B,b:A,special:"n"};break;case"odd":C={a:2,b:0,special:"n"};
-break;case"even":C={a:2,b:1,special:"n"};break;case"first":C={a:0,special:"index"};break;case"last":C={special:"last-child"};break;case"only":C={special:"only-child"};
-break;default:C={a:(B-1),special:"index"};}return Selectors.Cache.nth[F]=C;},parseSelector:function(E){if(Selectors.Cache.parsed[E]){return Selectors.Cache.parsed[E];
-}var D,H={classes:[],pseudos:[],attributes:[]};while((D=Selectors.RegExps.combined.exec(E))){var I=D[1],G=D[2],F=D[3],B=D[4],C=D[5],J=D[6];if(I){H.classes.push(I);
-}else{if(C){var A=Selectors.Pseudo.get(C);if(A){H.pseudos.push({parser:A,argument:J});}else{H.attributes.push({name:C,operator:"=",value:J});}}else{if(G){H.attributes.push({name:G,operator:F,value:B});
-}}}}if(!H.classes.length){delete H.classes;}if(!H.attributes.length){delete H.attributes;}if(!H.pseudos.length){delete H.pseudos;}if(!H.classes&&!H.attributes&&!H.pseudos){H=null;
-}return Selectors.Cache.parsed[E]=H;},parseTagAndID:function(B){var A=B.match(Selectors.RegExps.tag);var C=B.match(Selectors.RegExps.id);return[(A)?A[1]:"*",(C)?C[1]:false];
-},filter:function(F,C,E){var D;if(C.classes){for(D=C.classes.length;D--;D){var G=C.classes[D];if(!Selectors.Filters.byClass(F,G)){return false;}}}if(C.attributes){for(D=C.attributes.length;
-D--;D){var B=C.attributes[D];if(!Selectors.Filters.byAttribute(F,B.name,B.operator,B.value)){return false;}}}if(C.pseudos){for(D=C.pseudos.length;D--;D){var A=C.pseudos[D];
-if(!Selectors.Filters.byPseudo(F,A.parser,A.argument,E)){return false;}}}return true;},getByTagAndID:function(B,A,D){if(D){var C=(B.getElementById)?B.getElementById(D,true):Element.getElementById(B,D,true);
-return(C&&Selectors.Filters.byTag(C,A))?[C]:[];}else{return B.getElementsByTagName(A);}},search:function(J,I,O){var B=[];var C=I.trim().replace(Selectors.RegExps.splitter,function(Z,Y,X){B.push(Y);
-return":)"+X;}).split(":)");var K,F,E,V;for(var U=0,Q=C.length;U<Q;U++){var T=C[U];if(U==0&&Selectors.RegExps.quick.test(T)){K=J.getElementsByTagName(T);
-continue;}var A=B[U-1];var L=Selectors.Utils.parseTagAndID(T);var W=L[0],M=L[1];if(U==0){K=Selectors.Utils.getByTagAndID(J,W,M);}else{var D={},H=[];for(var S=0,R=K.length;
-S<R;S++){H=Selectors.Getters[A](H,K[S],W,M,D);}K=H;}var G=Selectors.Utils.parseSelector(T);if(G){E=[];for(var P=0,N=K.length;P<N;P++){V=K[P];if(Selectors.Utils.filter(V,G,O)){E.push(V);
-}}K=E;}}return K;}};Selectors.Getters={" ":function(H,G,I,A,E){var D=Selectors.Utils.getByTagAndID(G,I,A);for(var C=0,B=D.length;C<B;C++){var F=D[C];if(Selectors.Utils.chk(F,E)){H.push(F);
-}}return H;},">":function(H,G,I,A,F){var C=Selectors.Utils.getByTagAndID(G,I,A);for(var E=0,D=C.length;E<D;E++){var B=C[E];if(B.parentNode==G&&Selectors.Utils.chk(B,F)){H.push(B);
-}}return H;},"+":function(C,B,A,E,D){while((B=B.nextSibling)){if(B.nodeType==1){if(Selectors.Utils.chk(B,D)&&Selectors.Filters.byTag(B,A)&&Selectors.Filters.byID(B,E)){C.push(B);
-}break;}}return C;},"~":function(C,B,A,E,D){while((B=B.nextSibling)){if(B.nodeType==1){if(!Selectors.Utils.chk(B,D)){break;}if(Selectors.Filters.byTag(B,A)&&Selectors.Filters.byID(B,E)){C.push(B);
-}}}return C;}};Selectors.Filters={byTag:function(B,A){return(A=="*"||(B.tagName&&B.tagName.toLowerCase()==A));},byID:function(A,B){return(!B||(A.id&&A.id==B));
-},byClass:function(B,A){return(B.className&&B.className.contains(A," "));},byPseudo:function(A,D,C,B){return D.call(A,C,B);},byAttribute:function(C,D,B,E){var A=Element.prototype.getProperty.call(C,D);
-if(!A){return false;}if(!B||E==undefined){return true;}switch(B){case"=":return(A==E);case"*=":return(A.contains(E));case"^=":return(A.substr(0,E.length)==E);
-case"$=":return(A.substr(A.length-E.length)==E);case"!=":return(A!=E);case"~=":return A.contains(E," ");case"|=":return A.contains(E,"-");}return false;
-}};Selectors.Pseudo=new Hash({empty:function(){return !(this.innerText||this.textContent||"").length;},not:function(A){return !Element.match(this,A);},contains:function(A){return(this.innerText||this.textContent||"").contains(A);
-},"first-child":function(){return Selectors.Pseudo.index.call(this,0);},"last-child":function(){var A=this;while((A=A.nextSibling)){if(A.nodeType==1){return false;
-}}return true;},"only-child":function(){var B=this;while((B=B.previousSibling)){if(B.nodeType==1){return false;}}var A=this;while((A=A.nextSibling)){if(A.nodeType==1){return false;
-}}return true;},"nth-child":function(G,E){G=(G==undefined)?"n":G;var C=Selectors.Utils.parseNthArgument(G);if(C.special!="n"){return Selectors.Pseudo[C.special].call(this,C.a,E);
-}var F=0;E.positions=E.positions||{};var D=$uid(this);if(!E.positions[D]){var B=this;while((B=B.previousSibling)){if(B.nodeType!=1){continue;}F++;var A=E.positions[$uid(B)];
-if(A!=undefined){F=A+F;break;}}E.positions[D]=F;}return(E.positions[D]%C.a==C.b);},index:function(A){var B=this,C=0;while((B=B.previousSibling)){if(B.nodeType==1&&++C>A){return false;
-}}return(C==A);},even:function(B,A){return Selectors.Pseudo["nth-child"].call(this,"2n+1",A);},odd:function(B,A){return Selectors.Pseudo["nth-child"].call(this,"2n",A);
-}});Element.Events.domready={onAdd:function(A){if(Browser.loaded){A.call(this);}}};(function(){var B=function(){if(Browser.loaded){return ;}Browser.loaded=true;
-window.fireEvent("domready");document.fireEvent("domready");};switch(Browser.Engine.name){case"webkit":(function(){(["loaded","complete"].contains(document.readyState))?B():arguments.callee.delay(50);
-})();break;case"trident":var A=document.createElement("div");(function(){($try(function(){A.doScroll("left");return $(A).inject(document.body).set("html","temp").dispose();
-}))?B():arguments.callee.delay(50);})();break;default:window.addEvent("load",B);document.addEvent("DOMContentLoaded",B);}})();var JSON=new Hash({encode:function(B){switch($type(B)){case"string":return'"'+B.replace(/[\x00-\x1f\\"]/g,JSON.$replaceChars)+'"';
-case"array":return"["+String(B.map(JSON.encode).filter($defined))+"]";case"object":case"hash":var A=[];Hash.each(B,function(E,D){var C=JSON.encode(E);if(C){A.push(JSON.encode(D)+":"+C);
-}});return"{"+A+"}";case"number":case"boolean":return String(B);case false:return"null";}return null;},$specialChars:{"\b":"\\b","\t":"\\t","\n":"\\n","\f":"\\f","\r":"\\r",'"':'\\"',"\\":"\\\\"},$replaceChars:function(A){return JSON.$specialChars[A]||"\\u00"+Math.floor(A.charCodeAt()/16).toString(16)+(A.charCodeAt()%16).toString(16);
-},decode:function(string,secure){if($type(string)!="string"||!string.length){return null;}if(secure&&!(/^[,:{}\[\]0-9.\-+Eaeflnr-u \n\r\t]*$/).test(string.replace(/\\./g,"@").replace(/"[^"\\\n\r]*"/g,""))){return null;
-}return eval("("+string+")");}});Native.implement([Hash,Array,String,Number],{toJSON:function(){return JSON.encode(this);}});var Cookie=new Class({Implements:Options,options:{path:false,domain:false,duration:false,secure:false,document:document},initialize:function(B,A){this.key=B;
-this.setOptions(A);},write:function(B){B=encodeURIComponent(B);if(this.options.domain){B+="; domain="+this.options.domain;}if(this.options.path){B+="; path="+this.options.path;
-}if(this.options.duration){var A=new Date();A.setTime(A.getTime()+this.options.duration*24*60*60*1000);B+="; expires="+A.toGMTString();}if(this.options.secure){B+="; secure";
-}this.options.document.cookie=this.key+"="+B;return this;},read:function(){var A=this.options.document.cookie.match("(?:^|;)\\s*"+this.key.escapeRegExp()+"=([^;]*)");
-return(A)?decodeURIComponent(A[1]):null;},dispose:function(){new Cookie(this.key,$merge(this.options,{duration:-1})).write("");return this;}});Cookie.write=function(B,C,A){return new Cookie(B,A).write(C);
-};Cookie.read=function(A){return new Cookie(A).read();};Cookie.dispose=function(B,A){return new Cookie(B,A).dispose();};var Fx=new Class({Implements:[Chain,Events,Options],options:{fps:50,unit:false,duration:500,link:"ignore",transition:function(A){return -(Math.cos(Math.PI*A)-1)/2;
-}},initialize:function(A){this.subject=this.subject||this;this.setOptions(A);this.options.duration=Fx.Durations[this.options.duration]||this.options.duration.toInt();
-var B=this.options.wait;if(B===false){this.options.link="cancel";}},step:function(){var A=$time();if(A<this.time+this.options.duration){var B=this.options.transition((A-this.time)/this.options.duration);
-this.set(this.compute(this.from,this.to,B));}else{this.set(this.compute(this.from,this.to,1));this.complete();}},set:function(A){return A;},compute:function(C,B,A){return Fx.compute(C,B,A);
-},check:function(A){if(!this.timer){return true;}switch(this.options.link){case"cancel":this.cancel();return true;case"chain":this.chain(A.bind(this,Array.slice(arguments,1)));
-return false;}return false;},start:function(B,A){if(!this.check(arguments.callee,B,A)){return this;}this.from=B;this.to=A;this.time=0;this.startTimer();
-this.onStart();return this;},complete:function(){if(this.stopTimer()){this.onComplete();}return this;},cancel:function(){if(this.stopTimer()){this.onCancel();
-}return this;},onStart:function(){this.fireEvent("start",this.subject);},onComplete:function(){this.fireEvent("complete",this.subject);if(!this.callChain()){this.fireEvent("chainComplete",this.subject);
-}},onCancel:function(){this.fireEvent("cancel",this.subject).clearChain();},pause:function(){this.stopTimer();return this;},resume:function(){this.startTimer();
-return this;},stopTimer:function(){if(!this.timer){return false;}this.time=$time()-this.time;this.timer=$clear(this.timer);return true;},startTimer:function(){if(this.timer){return false;
-}this.time=$time()-this.time;this.timer=this.step.periodical(Math.round(1000/this.options.fps),this);return true;}});Fx.compute=function(C,B,A){return(B-C)*A+C;
-};Fx.Durations={"short":250,normal:500,"long":1000};Fx.CSS=new Class({Extends:Fx,prepare:function(D,E,B){B=$splat(B);var C=B[1];if(!$chk(C)){B[1]=B[0];
-B[0]=D.getStyle(E);}var A=B.map(this.parse);return{from:A[0],to:A[1]};},parse:function(A){A=$lambda(A)();A=(typeof A=="string")?A.split(" "):$splat(A);
-return A.map(function(C){C=String(C);var B=false;Fx.CSS.Parsers.each(function(F,E){if(B){return ;}var D=F.parse(C);if($chk(D)){B={value:D,parser:F};}});
-B=B||{value:C,parser:Fx.CSS.Parsers.String};return B;});},compute:function(D,C,B){var A=[];(Math.min(D.length,C.length)).times(function(E){A.push({value:D[E].parser.compute(D[E].value,C[E].value,B),parser:D[E].parser});
-});A.$family={name:"fx:css:value"};return A;},serve:function(C,B){if($type(C)!="fx:css:value"){C=this.parse(C);}var A=[];C.each(function(D){A=A.concat(D.parser.serve(D.value,B));
-});return A;},render:function(A,D,C,B){A.setStyle(D,this.serve(C,B));},search:function(A){if(Fx.CSS.Cache[A]){return Fx.CSS.Cache[A];}var B={};Array.each(document.styleSheets,function(E,D){var C=E.href;
-if(C&&C.contains("://")&&!C.contains(document.domain)){return ;}var F=E.rules||E.cssRules;Array.each(F,function(I,G){if(!I.style){return ;}var H=(I.selectorText)?I.selectorText.replace(/^\w+/,function(J){return J.toLowerCase();
-}):null;if(!H||!H.test("^"+A+"$")){return ;}Element.Styles.each(function(K,J){if(!I.style[J]||Element.ShortStyles[J]){return ;}K=String(I.style[J]);B[J]=(K.test(/^rgb/))?K.rgbToHex():K;
-});});});return Fx.CSS.Cache[A]=B;}});Fx.CSS.Cache={};Fx.CSS.Parsers=new Hash({Color:{parse:function(A){if(A.match(/^#[0-9a-f]{3,6}$/i)){return A.hexToRgb(true);
-}return((A=A.match(/(\d+),\s*(\d+),\s*(\d+)/)))?[A[1],A[2],A[3]]:false;},compute:function(C,B,A){return C.map(function(E,D){return Math.round(Fx.compute(C[D],B[D],A));
-});},serve:function(A){return A.map(Number);}},Number:{parse:parseFloat,compute:Fx.compute,serve:function(B,A){return(A)?B+A:B;}},String:{parse:$lambda(false),compute:$arguments(1),serve:$arguments(0)}});
-Fx.Tween=new Class({Extends:Fx.CSS,initialize:function(B,A){this.element=this.subject=$(B);this.parent(A);},set:function(B,A){if(arguments.length==1){A=B;
-B=this.property||this.options.property;}this.render(this.element,B,A,this.options.unit);return this;},start:function(C,E,D){if(!this.check(arguments.callee,C,E,D)){return this;
-}var B=Array.flatten(arguments);this.property=this.options.property||B.shift();var A=this.prepare(this.element,this.property,B);return this.parent(A.from,A.to);
-}});Element.Properties.tween={set:function(A){var B=this.retrieve("tween");if(B){B.cancel();}return this.eliminate("tween").store("tween:options",$extend({link:"cancel"},A));
-},get:function(A){if(A||!this.retrieve("tween")){if(A||!this.retrieve("tween:options")){this.set("tween",A);}this.store("tween",new Fx.Tween(this,this.retrieve("tween:options")));
-}return this.retrieve("tween");}};Element.implement({tween:function(A,C,B){this.get("tween").start(arguments);return this;},fade:function(C){var E=this.get("tween"),D="opacity",A;
-C=$pick(C,"toggle");switch(C){case"in":E.start(D,1);break;case"out":E.start(D,0);break;case"show":E.set(D,1);break;case"hide":E.set(D,0);break;case"toggle":var B=this.retrieve("fade:flag",this.get("opacity")==1);
-E.start(D,(B)?0:1);this.store("fade:flag",!B);A=true;break;default:E.start(D,arguments);}if(!A){this.eliminate("fade:flag");}return this;},highlight:function(C,A){if(!A){A=this.retrieve("highlight:original",this.getStyle("background-color"));
-A=(A=="transparent")?"#fff":A;}var B=this.get("tween");B.start("background-color",C||"#ffff88",A).chain(function(){this.setStyle("background-color",this.retrieve("highlight:original"));
-B.callChain();}.bind(this));return this;}});Fx.Morph=new Class({Extends:Fx.CSS,initialize:function(B,A){this.element=this.subject=$(B);this.parent(A);},set:function(A){if(typeof A=="string"){A=this.search(A);
-}for(var B in A){this.render(this.element,B,A[B],this.options.unit);}return this;},compute:function(E,D,C){var A={};for(var B in E){A[B]=this.parent(E[B],D[B],C);
-}return A;},start:function(B){if(!this.check(arguments.callee,B)){return this;}if(typeof B=="string"){B=this.search(B);}var E={},D={};for(var C in B){var A=this.prepare(this.element,C,B[C]);
-E[C]=A.from;D[C]=A.to;}return this.parent(E,D);}});Element.Properties.morph={set:function(A){var B=this.retrieve("morph");if(B){B.cancel();}return this.eliminate("morph").store("morph:options",$extend({link:"cancel"},A));
-},get:function(A){if(A||!this.retrieve("morph")){if(A||!this.retrieve("morph:options")){this.set("morph",A);}this.store("morph",new Fx.Morph(this,this.retrieve("morph:options")));
-}return this.retrieve("morph");}};Element.implement({morph:function(A){this.get("morph").start(A);return this;}});(function(){var A=Fx.prototype.initialize;
-Fx.prototype.initialize=function(B){A.call(this,B);var C=this.options.transition;if(typeof C=="string"&&(C=C.split(":"))){var D=Fx.Transitions;D=D[C[0]]||D[C[0].capitalize()];
-if(C[1]){D=D["ease"+C[1].capitalize()+(C[2]?C[2].capitalize():"")];}this.options.transition=D;}};})();Fx.Transition=function(B,A){A=$splat(A);return $extend(B,{easeIn:function(C){return B(C,A);
-},easeOut:function(C){return 1-B(1-C,A);},easeInOut:function(C){return(C<=0.5)?B(2*C,A)/2:(2-B(2*(1-C),A))/2;}});};Fx.Transitions=new Hash({linear:$arguments(0)});
-Fx.Transitions.extend=function(A){for(var B in A){Fx.Transitions[B]=new Fx.Transition(A[B]);}};Fx.Transitions.extend({Pow:function(B,A){return Math.pow(B,A[0]||6);
-},Expo:function(A){return Math.pow(2,8*(A-1));},Circ:function(A){return 1-Math.sin(Math.acos(A));},Sine:function(A){return 1-Math.sin((1-A)*Math.PI/2);
-},Back:function(B,A){A=A[0]||1.618;return Math.pow(B,2)*((A+1)*B-A);},Bounce:function(D){var C;for(var B=0,A=1;1;B+=A,A/=2){if(D>=(7-4*B)/11){C=-Math.pow((11-6*B-11*D)/4,2)+A*A;
-break;}}return C;},Elastic:function(B,A){return Math.pow(2,10*--B)*Math.cos(20*B*Math.PI*(A[0]||1)/3);}});["Quad","Cubic","Quart","Quint"].each(function(B,A){Fx.Transitions[B]=new Fx.Transition(function(C){return Math.pow(C,[A+2]);
-});});var Request=new Class({Implements:[Chain,Events,Options],options:{url:"",data:"",headers:{"X-Requested-With":"XMLHttpRequest",Accept:"text/javascript, text/html, application/xml, text/xml, */*"},async:true,format:false,method:"post",link:"ignore",isSuccess:null,emulation:true,urlEncoded:true,encoding:"utf-8",evalScripts:false,evalResponse:false},initialize:function(A){this.xhr=new Browser.Request();
-this.setOptions(A);this.options.isSuccess=this.options.isSuccess||this.isSuccess;this.headers=new Hash(this.options.headers);},onStateChange:function(){if(this.xhr.readyState!=4||!this.running){return ;
-}this.running=false;this.status=0;$try(function(){this.status=this.xhr.status;}.bind(this));if(this.options.isSuccess.call(this,this.status)){this.response={text:this.xhr.responseText,xml:this.xhr.responseXML};
-this.success(this.response.text,this.response.xml);}else{this.response={text:null,xml:null};this.failure();}this.xhr.onreadystatechange=$empty;},isSuccess:function(){return((this.status>=200)&&(this.status<300));
-},processScripts:function(A){if(this.options.evalResponse||(/(ecma|java)script/).test(this.getHeader("Content-type"))){return $exec(A);}return A.stripScripts(this.options.evalScripts);
-},success:function(B,A){this.onSuccess(this.processScripts(B),A);},onSuccess:function(){this.fireEvent("complete",arguments).fireEvent("success",arguments).callChain();
-},failure:function(){this.onFailure();},onFailure:function(){this.fireEvent("complete").fireEvent("failure",this.xhr);},setHeader:function(A,B){this.headers.set(A,B);
-return this;},getHeader:function(A){return $try(function(){return this.xhr.getResponseHeader(A);}.bind(this));},check:function(A){if(!this.running){return true;
-}switch(this.options.link){case"cancel":this.cancel();return true;case"chain":this.chain(A.bind(this,Array.slice(arguments,1)));return false;}return false;
-},send:function(I){if(!this.check(arguments.callee,I)){return this;}this.running=true;var G=$type(I);if(G=="string"||G=="element"){I={data:I};}var D=this.options;
-I=$extend({data:D.data,url:D.url,method:D.method},I);var E=I.data,B=I.url,A=I.method;switch($type(E)){case"element":E=$(E).toQueryString();break;case"object":case"hash":E=Hash.toQueryString(E);
-}if(this.options.format){var H="format="+this.options.format;E=(E)?H+"&"+E:H;}if(this.options.emulation&&["put","delete"].contains(A)){var F="_method="+A;
-E=(E)?F+"&"+E:F;A="post";}if(this.options.urlEncoded&&A=="post"){var C=(this.options.encoding)?"; charset="+this.options.encoding:"";this.headers.set("Content-type","application/x-www-form-urlencoded"+C);
-}if(E&&A=="get"){B=B+(B.contains("?")?"&":"?")+E;E=null;}this.xhr.open(A.toUpperCase(),B,this.options.async);this.xhr.onreadystatechange=this.onStateChange.bind(this);
-this.headers.each(function(K,J){if(!$try(function(){this.xhr.setRequestHeader(J,K);return true;}.bind(this))){this.fireEvent("exception",[J,K]);}},this);
-this.fireEvent("request");this.xhr.send(E);if(!this.options.async){this.onStateChange();}return this;},cancel:function(){if(!this.running){return this;
-}this.running=false;this.xhr.abort();this.xhr.onreadystatechange=$empty;this.xhr=new Browser.Request();this.fireEvent("cancel");return this;}});(function(){var A={};
-["get","post","put","delete","GET","POST","PUT","DELETE"].each(function(B){A[B]=function(){var C=Array.link(arguments,{url:String.type,data:$defined});
-return this.send($extend(C,{method:B.toLowerCase()}));};});Request.implement(A);})();Element.Properties.send={set:function(A){var B=this.retrieve("send");
-if(B){B.cancel();}return this.eliminate("send").store("send:options",$extend({data:this,link:"cancel",method:this.get("method")||"post",url:this.get("action")},A));
-},get:function(A){if(A||!this.retrieve("send")){if(A||!this.retrieve("send:options")){this.set("send",A);}this.store("send",new Request(this.retrieve("send:options")));
-}return this.retrieve("send");}};Element.implement({send:function(A){var B=this.get("send");B.send({data:this,url:A||B.options.url});return this;}});Request.HTML=new Class({Extends:Request,options:{update:false,evalScripts:true,filter:false},processHTML:function(C){var B=C.match(/<body[^>]*>([\s\S]*?)<\/body>/i);
-C=(B)?B[1]:C;var A=new Element("div");return $try(function(){var D="<root>"+C+"</root>",G;if(Browser.Engine.trident){G=new ActiveXObject("Microsoft.XMLDOM");
-G.async=false;G.loadXML(D);}else{G=new DOMParser().parseFromString(D,"text/xml");}D=G.getElementsByTagName("root")[0];for(var F=0,E=D.childNodes.length;
-F<E;F++){var H=Element.clone(D.childNodes[F],true,true);if(H){A.grab(H);}}return A;})||A.set("html",C);},success:function(D){var C=this.options,B=this.response;
-B.html=D.stripScripts(function(E){B.javascript=E;});var A=this.processHTML(B.html);B.tree=A.childNodes;B.elements=A.getElements("*");if(C.filter){B.tree=B.elements.filter(C.filter);
-}if(C.update){$(C.update).empty().adopt(B.tree);}if(C.evalScripts){$exec(B.javascript);}this.onSuccess(B.tree,B.elements,B.html,B.javascript);}});Element.Properties.load={set:function(A){var B=this.retrieve("load");
-if(B){send.cancel();}return this.eliminate("load").store("load:options",$extend({data:this,link:"cancel",update:this,method:"get"},A));},get:function(A){if(A||!this.retrieve("load")){if(A||!this.retrieve("load:options")){this.set("load",A);
-}this.store("load",new Request.HTML(this.retrieve("load:options")));}return this.retrieve("load");}};Element.implement({load:function(){this.get("load").send(Array.link(arguments,{data:Object.type,url:String.type}));
-return this;}});Request.JSON=new Class({Extends:Request,options:{secure:true},initialize:function(A){this.parent(A);this.headers.extend({Accept:"application/json","X-Request":"JSON"});
-},success:function(A){this.response.json=JSON.decode(A,this.options.secure);this.onSuccess(this.response.json,A);}});
\ No newline at end of file

=== removed file 'loggerhead/static/javascript/mootools-1.2-more.js'
--- loggerhead/static/javascript/mootools-1.2-more.js	2008-06-18 07:49:45 +0000
+++ loggerhead/static/javascript/mootools-1.2-more.js	1970-01-01 00:00:00 +0000
@@ -1,97 +0,0 @@
-//MooTools More, <http://mootools.net/more>. Copyright (c) 2006-2008 Valerio Proietti, <http://mad4milk.net>, MIT Style License.
-
-Fx.Slide=new Class({Extends:Fx,options:{mode:"vertical"},initialize:function(B,A){this.addEvent("complete",function(){this.open=(this.wrapper["offset"+this.layout.capitalize()]!=0);
-if(this.open&&Browser.Engine.webkit419){this.element.dispose().inject(this.wrapper);}},true);this.element=this.subject=$(B);this.parent(A);var C=this.element.retrieve("wrapper");
-this.wrapper=C||new Element("div",{styles:$extend(this.element.getStyles("margin","position"),{overflow:"hidden"})}).wraps(this.element);this.element.store("wrapper",this.wrapper).setStyle("margin",0);
-this.now=[];this.open=true;},vertical:function(){this.margin="margin-top";this.layout="height";this.offset=this.element.offsetHeight;},horizontal:function(){this.margin="margin-left";
-this.layout="width";this.offset=this.element.offsetWidth;},set:function(A){this.element.setStyle(this.margin,A[0]);this.wrapper.setStyle(this.layout,A[1]);
-return this;},compute:function(E,D,C){var B=[];var A=2;A.times(function(F){B[F]=Fx.compute(E[F],D[F],C);});return B;},start:function(B,E){if(!this.check(arguments.callee,B,E)){return this;
-}this[E||this.options.mode]();var D=this.element.getStyle(this.margin).toInt();var C=this.wrapper.getStyle(this.layout).toInt();var A=[[D,C],[0,this.offset]];
-var G=[[D,C],[-this.offset,0]];var F;switch(B){case"in":F=A;break;case"out":F=G;break;case"toggle":F=(this.wrapper["offset"+this.layout.capitalize()]==0)?A:G;
-}return this.parent(F[0],F[1]);},slideIn:function(A){return this.start("in",A);},slideOut:function(A){return this.start("out",A);},hide:function(A){this[A||this.options.mode]();
-this.open=false;return this.set([-this.offset,0]);},show:function(A){this[A||this.options.mode]();this.open=true;return this.set([0,this.offset]);},toggle:function(A){return this.start("toggle",A);
-}});Element.Properties.slide={set:function(B){var A=this.retrieve("slide");if(A){A.cancel();}return this.eliminate("slide").store("slide:options",$extend({link:"cancel"},B));
-},get:function(A){if(A||!this.retrieve("slide")){if(A||!this.retrieve("slide:options")){this.set("slide",A);}this.store("slide",new Fx.Slide(this,this.retrieve("slide:options")));
-}return this.retrieve("slide");}};Element.implement({slide:function(D,E){D=D||"toggle";var B=this.get("slide"),A;switch(D){case"hide":B.hide(E);break;case"show":B.show(E);
-break;case"toggle":var C=this.retrieve("slide:flag",B.open);B[(C)?"slideOut":"slideIn"](E);this.store("slide:flag",!C);A=true;break;default:B.start(D,E);
-}if(!A){this.eliminate("slide:flag");}return this;}});Fx.Elements=new Class({Extends:Fx.CSS,initialize:function(B,A){this.elements=this.subject=$$(B);this.parent(A);
-},compute:function(G,H,I){var C={};for(var D in G){var A=G[D],E=H[D],F=C[D]={};for(var B in A){F[B]=this.parent(A[B],E[B],I);}}return C;},set:function(B){for(var C in B){var A=B[C];
-for(var D in A){this.render(this.elements[C],D,A[D],this.options.unit);}}return this;},start:function(C){if(!this.check(arguments.callee,C)){return this;
-}var H={},I={};for(var D in C){var F=C[D],A=H[D]={},G=I[D]={};for(var B in F){var E=this.prepare(this.elements[D],B,F[B]);A[B]=E.from;G[B]=E.to;}}return this.parent(H,I);
-}});var Drag=new Class({Implements:[Events,Options],options:{snap:6,unit:"px",grid:false,style:true,limit:false,handle:false,invert:false,preventDefault:false,modifiers:{x:"left",y:"top"}},initialize:function(){var B=Array.link(arguments,{options:Object.type,element:$defined});
-this.element=$(B.element);this.document=this.element.getDocument();this.setOptions(B.options||{});var A=$type(this.options.handle);this.handles=(A=="array"||A=="collection")?$$(this.options.handle):$(this.options.handle)||this.element;
-this.mouse={now:{},pos:{}};this.value={start:{},now:{}};this.selection=(Browser.Engine.trident)?"selectstart":"mousedown";this.bound={start:this.start.bind(this),check:this.check.bind(this),drag:this.drag.bind(this),stop:this.stop.bind(this),cancel:this.cancel.bind(this),eventStop:$lambda(false)};
-this.attach();},attach:function(){this.handles.addEvent("mousedown",this.bound.start);return this;},detach:function(){this.handles.removeEvent("mousedown",this.bound.start);
-return this;},start:function(C){if(this.options.preventDefault){C.preventDefault();}this.fireEvent("beforeStart",this.element);this.mouse.start=C.page;
-var A=this.options.limit;this.limit={x:[],y:[]};for(var D in this.options.modifiers){if(!this.options.modifiers[D]){continue;}if(this.options.style){this.value.now[D]=this.element.getStyle(this.options.modifiers[D]).toInt();
-}else{this.value.now[D]=this.element[this.options.modifiers[D]];}if(this.options.invert){this.value.now[D]*=-1;}this.mouse.pos[D]=C.page[D]-this.value.now[D];
-if(A&&A[D]){for(var B=2;B--;B){if($chk(A[D][B])){this.limit[D][B]=$lambda(A[D][B])();}}}}if($type(this.options.grid)=="number"){this.options.grid={x:this.options.grid,y:this.options.grid};
-}this.document.addEvents({mousemove:this.bound.check,mouseup:this.bound.cancel});this.document.addEvent(this.selection,this.bound.eventStop);},check:function(A){if(this.options.preventDefault){A.preventDefault();
-}var B=Math.round(Math.sqrt(Math.pow(A.page.x-this.mouse.start.x,2)+Math.pow(A.page.y-this.mouse.start.y,2)));if(B>this.options.snap){this.cancel();this.document.addEvents({mousemove:this.bound.drag,mouseup:this.bound.stop});
-this.fireEvent("start",this.element).fireEvent("snap",this.element);}},drag:function(A){if(this.options.preventDefault){A.preventDefault();}this.mouse.now=A.page;
-for(var B in this.options.modifiers){if(!this.options.modifiers[B]){continue;}this.value.now[B]=this.mouse.now[B]-this.mouse.pos[B];if(this.options.invert){this.value.now[B]*=-1;
-}if(this.options.limit&&this.limit[B]){if($chk(this.limit[B][1])&&(this.value.now[B]>this.limit[B][1])){this.value.now[B]=this.limit[B][1];}else{if($chk(this.limit[B][0])&&(this.value.now[B]<this.limit[B][0])){this.value.now[B]=this.limit[B][0];
-}}}if(this.options.grid[B]){this.value.now[B]-=(this.value.now[B]%this.options.grid[B]);}if(this.options.style){this.element.setStyle(this.options.modifiers[B],this.value.now[B]+this.options.unit);
-}else{this.element[this.options.modifiers[B]]=this.value.now[B];}}this.fireEvent("drag",this.element);},cancel:function(A){this.document.removeEvent("mousemove",this.bound.check);
-this.document.removeEvent("mouseup",this.bound.cancel);if(A){this.document.removeEvent(this.selection,this.bound.eventStop);this.fireEvent("cancel",this.element);
-}},stop:function(A){this.document.removeEvent(this.selection,this.bound.eventStop);this.document.removeEvent("mousemove",this.bound.drag);this.document.removeEvent("mouseup",this.bound.stop);
-if(A){this.fireEvent("complete",this.element);}}});Element.implement({makeResizable:function(A){return new Drag(this,$merge({modifiers:{x:"width",y:"height"}},A));
-}});Hash.Cookie=new Class({Extends:Cookie,options:{autoSave:true},initialize:function(B,A){this.parent(B,A);this.load();},save:function(){var A=JSON.encode(this.hash);
-if(!A||A.length>4096){return false;}if(A=="{}"){this.dispose();}else{this.write(A);}return true;},load:function(){this.hash=new Hash(JSON.decode(this.read(),true));
-return this;}});Hash.Cookie.implement((function(){var A={};Hash.each(Hash.prototype,function(C,B){A[B]=function(){var D=C.apply(this.hash,arguments);if(this.options.autoSave){this.save();
-}return D;};});return A;})());var Color=new Native({initialize:function(B,C){if(arguments.length>=3){C="rgb";B=Array.slice(arguments,0,3);}else{if(typeof B=="string"){if(B.match(/rgb/)){B=B.rgbToHex().hexToRgb(true);
-}else{if(B.match(/hsb/)){B=B.hsbToRgb();}else{B=B.hexToRgb(true);}}}}C=C||"rgb";switch(C){case"hsb":var A=B;B=B.hsbToRgb();B.hsb=A;break;case"hex":B=B.hexToRgb(true);
-break;}B.rgb=B.slice(0,3);B.hsb=B.hsb||B.rgbToHsb();B.hex=B.rgbToHex();return $extend(B,this);}});Color.implement({mix:function(){var A=Array.slice(arguments);
-var C=($type(A.getLast())=="number")?A.pop():50;var B=this.slice();A.each(function(D){D=new Color(D);for(var E=0;E<3;E++){B[E]=Math.round((B[E]/100*(100-C))+(D[E]/100*C));
-}});return new Color(B,"rgb");},invert:function(){return new Color(this.map(function(A){return 255-A;}));},setHue:function(A){return new Color([A,this.hsb[1],this.hsb[2]],"hsb");
-},setSaturation:function(A){return new Color([this.hsb[0],A,this.hsb[2]],"hsb");},setBrightness:function(A){return new Color([this.hsb[0],this.hsb[1],A],"hsb");
-}});function $RGB(C,B,A){return new Color([C,B,A],"rgb");}function $HSB(C,B,A){return new Color([C,B,A],"hsb");}function $HEX(A){return new Color(A,"hex");
-}Array.implement({rgbToHsb:function(){var B=this[0],C=this[1],J=this[2];var G,F,H;var I=Math.max(B,C,J),E=Math.min(B,C,J);var K=I-E;H=I/255;F=(I!=0)?K/I:0;
-if(F==0){G=0;}else{var D=(I-B)/K;var A=(I-C)/K;var L=(I-J)/K;if(B==I){G=L-A;}else{if(C==I){G=2+D-L;}else{G=4+A-D;}}G/=6;if(G<0){G++;}}return[Math.round(G*360),Math.round(F*100),Math.round(H*100)];
-},hsbToRgb:function(){var C=Math.round(this[2]/100*255);if(this[1]==0){return[C,C,C];}else{var A=this[0]%360;var E=A%60;var F=Math.round((this[2]*(100-this[1]))/10000*255);
-var D=Math.round((this[2]*(6000-this[1]*E))/600000*255);var B=Math.round((this[2]*(6000-this[1]*(60-E)))/600000*255);switch(Math.floor(A/60)){case 0:return[C,B,F];
-case 1:return[D,C,F];case 2:return[F,C,B];case 3:return[F,D,C];case 4:return[B,F,C];case 5:return[C,F,D];}}return false;}});String.implement({rgbToHsb:function(){var A=this.match(/\d{1,3}/g);
-return(A)?hsb.rgbToHsb():null;},hsbToRgb:function(){var A=this.match(/\d{1,3}/g);return(A)?A.hsbToRgb():null;}});var Group=new Class({initialize:function(){this.instances=Array.flatten(arguments);
-this.events={};this.checker={};},addEvent:function(B,A){this.checker[B]=this.checker[B]||{};this.events[B]=this.events[B]||[];if(this.events[B].contains(A)){return false;
-}else{this.events[B].push(A);}this.instances.each(function(C,D){C.addEvent(B,this.check.bind(this,[B,C,D]));},this);return this;},check:function(C,A,B){this.checker[C][B]=true;
-var D=this.instances.every(function(F,E){return this.checker[C][E]||false;},this);if(!D){return ;}this.checker[C]={};this.events[C].each(function(E){E.call(this,this.instances,A);
-},this);}});var Asset=new Hash({javascript:function(F,D){D=$extend({onload:$empty,document:document,check:$lambda(true)},D);var B=new Element("script",{src:F,type:"text/javascript"});
-var E=D.onload.bind(B),A=D.check,G=D.document;delete D.onload;delete D.check;delete D.document;B.addEvents({load:E,readystatechange:function(){if(["loaded","complete"].contains(this.readyState)){E();
-}}}).setProperties(D);if(Browser.Engine.webkit419){var C=(function(){if(!$try(A)){return ;}$clear(C);E();}).periodical(50);}return B.inject(G.head);},css:function(B,A){return new Element("link",$merge({rel:"stylesheet",media:"screen",type:"text/css",href:B},A)).inject(document.head);
-},image:function(C,B){B=$merge({onload:$empty,onabort:$empty,onerror:$empty},B);var D=new Image();var A=$(D)||new Element("img");["load","abort","error"].each(function(E){var F="on"+E;
-var G=B[F];delete B[F];D[F]=function(){if(!D){return ;}if(!A.parentNode){A.width=D.width;A.height=D.height;}D=D.onload=D.onabort=D.onerror=null;G.delay(1,A,A);
-A.fireEvent(E,A,1);};});D.src=A.src=C;if(D&&D.complete){D.onload.delay(1);}return A.setProperties(B);},images:function(D,C){C=$merge({onComplete:$empty,onProgress:$empty},C);
-if(!D.push){D=[D];}var A=[];var B=0;D.each(function(F){var E=new Asset.image(F,{onload:function(){C.onProgress.call(this,B,D.indexOf(F));B++;if(B==D.length){C.onComplete();
-}}});A.push(E);});return new Elements(A);}});var Tips=new Class({Implements:[Events,Options],options:{onShow:function(A){A.setStyle("visibility","visible");
-},onHide:function(A){A.setStyle("visibility","hidden");},showDelay:100,hideDelay:100,className:null,offsets:{x:16,y:16},fixed:false},initialize:function(){var C=Array.link(arguments,{options:Object.type,elements:$defined});
-this.setOptions(C.options||null);this.tip=new Element("div").inject(document.body);if(this.options.className){this.tip.addClass(this.options.className);
-}var B=new Element("div",{"class":"tip-top"}).inject(this.tip);this.container=new Element("div",{"class":"tip"}).inject(this.tip);var A=new Element("div",{"class":"tip-bottom"}).inject(this.tip);
-this.tip.setStyles({position:"absolute",top:0,left:0,visibility:"hidden"});if(C.elements){this.attach(C.elements);}},attach:function(A){$$(A).each(function(D){var G=D.retrieve("tip:title",D.get("title"));
-var F=D.retrieve("tip:text",D.get("rel")||D.get("href"));var E=D.retrieve("tip:enter",this.elementEnter.bindWithEvent(this,D));var C=D.retrieve("tip:leave",this.elementLeave.bindWithEvent(this,D));
-D.addEvents({mouseenter:E,mouseleave:C});if(!this.options.fixed){var B=D.retrieve("tip:move",this.elementMove.bindWithEvent(this,D));D.addEvent("mousemove",B);
-}D.store("tip:native",D.get("title"));D.erase("title");},this);return this;},detach:function(A){$$(A).each(function(C){C.removeEvent("mouseenter",C.retrieve("tip:enter")||$empty);
-C.removeEvent("mouseleave",C.retrieve("tip:leave")||$empty);C.removeEvent("mousemove",C.retrieve("tip:move")||$empty);C.eliminate("tip:enter").eliminate("tip:leave").eliminate("tip:move");
-var B=C.retrieve("tip:native");if(B){C.set("title",B);}});return this;},elementEnter:function(B,A){$A(this.container.childNodes).each(Element.dispose);
-var D=A.retrieve("tip:title");if(D){this.titleElement=new Element("div",{"class":"tip-title"}).inject(this.container);this.fill(this.titleElement,D);}var C=A.retrieve("tip:text");
-if(C){this.textElement=new Element("div",{"class":"tip-text"}).inject(this.container);this.fill(this.textElement,C);}this.timer=$clear(this.timer);this.timer=this.show.delay(this.options.showDelay,this);
-this.position((!this.options.fixed)?B:{page:A.getPosition()});},elementLeave:function(A){$clear(this.timer);this.timer=this.hide.delay(this.options.hideDelay,this);
-},elementMove:function(A){this.position(A);},position:function(D){var B=window.getSize(),A=window.getScroll();var E={x:this.tip.offsetWidth,y:this.tip.offsetHeight};
-var C={x:"left",y:"top"};for(var F in C){var G=D.page[F]+this.options.offsets[F];if((G+E[F]-A[F])>B[F]){G=D.page[F]-this.options.offsets[F]-E[F];}this.tip.setStyle(C[F],G);
-}},fill:function(A,B){(typeof B=="string")?A.set("html",B):A.adopt(B);},show:function(){this.fireEvent("show",this.tip);},hide:function(){this.fireEvent("hide",this.tip);
-}});var Slider=new Class({Implements:[Events,Options],options:{onTick:function(A){if(this.options.snap){A=this.toPosition(this.step);}this.knob.setStyle(this.property,A);
-},snap:false,offset:0,range:false,wheel:false,steps:100,mode:"horizontal"},initialize:function(E,A,D){this.setOptions(D);this.element=$(E);this.knob=$(A);
-this.previousChange=this.previousEnd=this.step=-1;this.element.addEvent("mousedown",this.clickedElement.bind(this));if(this.options.wheel){this.element.addEvent("mousewheel",this.scrolledElement.bindWithEvent(this));
-}var F,B={},C={x:false,y:false};switch(this.options.mode){case"vertical":this.axis="y";this.property="top";F="offsetHeight";break;case"horizontal":this.axis="x";
-this.property="left";F="offsetWidth";}this.half=this.knob[F]/2;this.full=this.element[F]-this.knob[F]+(this.options.offset*2);this.min=$chk(this.options.range[0])?this.options.range[0]:0;
-this.max=$chk(this.options.range[1])?this.options.range[1]:this.options.steps;this.range=this.max-this.min;this.steps=this.options.steps||this.full;this.stepSize=Math.abs(this.range)/this.steps;
-this.stepWidth=this.stepSize*this.full/Math.abs(this.range);this.knob.setStyle("position","relative").setStyle(this.property,-this.options.offset);C[this.axis]=this.property;
-B[this.axis]=[-this.options.offset,this.full-this.options.offset];this.drag=new Drag(this.knob,{snap:0,limit:B,modifiers:C,onDrag:this.draggedKnob.bind(this),onStart:this.draggedKnob.bind(this),onComplete:function(){this.draggedKnob();
-this.end();}.bind(this)});if(this.options.snap){this.drag.options.grid=Math.ceil(this.stepWidth);this.drag.options.limit[this.axis][1]=this.full;}},set:function(A){if(!((this.range>0)^(A<this.min))){A=this.min;
-}if(!((this.range>0)^(A>this.max))){A=this.max;}this.step=Math.round(A);this.checkStep();this.end();this.fireEvent("tick",this.toPosition(this.step));return this;
-},clickedElement:function(C){var B=this.range<0?-1:1;var A=C.page[this.axis]-this.element.getPosition()[this.axis]-this.half;A=A.limit(-this.options.offset,this.full-this.options.offset);
-this.step=Math.round(this.min+B*this.toStep(A));this.checkStep();this.end();this.fireEvent("tick",A);},scrolledElement:function(A){var B=(this.options.mode=="horizontal")?(A.wheel<0):(A.wheel>0);
-this.set(B?this.step-this.stepSize:this.step+this.stepSize);A.stop();},draggedKnob:function(){var B=this.range<0?-1:1;var A=this.drag.value.now[this.axis];
-A=A.limit(-this.options.offset,this.full-this.options.offset);this.step=Math.round(this.min+B*this.toStep(A));this.checkStep();},checkStep:function(){if(this.previousChange!=this.step){this.previousChange=this.step;
-this.fireEvent("change",this.step);}},end:function(){if(this.previousEnd!==this.step){this.previousEnd=this.step;this.fireEvent("complete",this.step+"");
-}},toStep:function(A){var B=(A+this.options.offset)*this.stepSize/this.full*this.steps;return this.options.steps?Math.round(B-=B%this.stepSize):B;},toPosition:function(A){return(this.full*Math.abs(this.min-A))/(this.steps*this.stepSize)-this.options.offset;
-}});
\ No newline at end of file

=== modified file 'loggerhead/templatefunctions.py'
--- loggerhead/templatefunctions.py	2009-01-23 20:39:54 +0000
+++ loggerhead/templatefunctions.py	2009-02-18 10:36:48 +0000
@@ -54,7 +54,10 @@
 
 @templatefunc
 def branchinfo(branch):
-    return _pt('branchinfo').expand(branch=branch, **templatefunctions)
+    if branch.served_url is not None:
+        return _pt('branchinfo').expand(branch=branch, **templatefunctions)
+    else:
+        return ''
 
 
 @templatefunc

=== modified file 'loggerhead/templates/annotate.pt'
--- loggerhead/templates/annotate.pt	2009-01-23 20:53:40 +0000
+++ loggerhead/templates/annotate.pt	2009-02-23 20:32:43 +0000
@@ -35,11 +35,10 @@
                 <a tal:attributes="href python:url(['/files', change.revno], clear=1)">browse files</a>
             </li>
             <li>
-                <a tal:attributes="href python:url(['/revision'], clear=1, start_revid=change.revno)">view revision</a>
+                <a tal:attributes="href python:url(['/revision', change.revno], clear=1)">view revision</a>
             </li>
             <li>
-                <a tal:attributes="href python:url(['/changes'], clear=1, 
-                                    start_revid=change.revno, filter_file_id=file_id)"
+                <a tal:attributes="href python:url(['/changes'], clear=1, filter_file_id=file_id)"
                 >view changes to this file</a>
             </li>
             <li id="last">
@@ -63,7 +62,7 @@
             <td class="annoRev">
               <a tal:condition="python:line.status=='changed'"
                  tal:content="python:util.trunc(line.change.revno)"
-                 tal:attributes="href python:url(['/revision'], clear=1, start_revid=line.change.revno, filter_file_id=file_id);
+                 tal:attributes="href python:url(['/revision', line.change.revno], clear=1);
                                  title python:'%s by %s, on %s (%s)'%(line.change.revno, util.hide_email(line.change.author), line.change.date.strftime('%d %b %Y %H:%M'), util.date_time(line.change.date))"></a>
             </td>
             <td class="annoCont" tal:content="line/text"></td>

=== modified file 'loggerhead/templates/changelog.pt'
--- loggerhead/templates/changelog.pt	2009-01-23 20:53:40 +0000
+++ loggerhead/templates/changelog.pt	2009-02-26 21:01:19 +0000
@@ -1,169 +1,169 @@
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<tal:block define="onload string:sortCollapseElements()">
-  <html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
-    <head>
-      <title metal:fill-slot="title"
-             tal:content="string:${branch/friendly_name} : changes"></title>
-      <metal:block fill-slot="header_extras">
-        <link rel="alternate" type="application/atom+xml"
-              tal:attributes="href python:url(['/atom']);
-                              title string:RSS feed for ${branch/friendly_name}" />
-      </metal:block>
-    </head>
+<html xmlns="http://www.w3.org/1999/xhtml" metal:use-macro="macros/main">
+  <head>
+    <title metal:fill-slot="title"
+           tal:content="string:${branch/friendly_name} : changes"></title>
+    <metal:block fill-slot="header_extras">
+      <link rel="alternate" type="application/atom+xml"
+            tal:attributes="href python:url(['/atom']);
+                            title string:RSS feed for ${branch/friendly_name}" />
+      <script type="text/javascript"
+              tal:attributes="src python:branch.static_url('/static/javascript/changelog.js')"></script>
+    </metal:block>
+  </head>
 
-    <body>
-        <tal:block metal:fill-slot="heading">
-         <h1>
-           <tal:has-link condition="branch/branch_link">
-             <a tal:attributes="href branch/branch_link"
-                tal:content="branch/friendly_name">
-               nice/branch/name
-             </a>
-           </tal:has-link>
-           <tal:no-link condition="not: branch/branch_link">
-             <span metal:use-macro="breadcrumbs/directory"></span>
-           </tal:no-link>
-           <tal:block condition="changes">
-             : changes
-             <tal:block condition="filter_file_id">to <span tal:content="python:history.get_path(revid, filter_file_id)" /></tal:block>
-             <tal:block condition="start_revid">from revision
-               <span tal:content="python:history.get_revno(start_revid)"/>
-             </tal:block>
-             <tal:block condition="query">matching <tal:block content="query" /></tal:block>
-           </tal:block>
-         </h1>
+  <body>
+    <tal:block metal:fill-slot="heading">
+      <h1>
+        <tal:has-link condition="branch/branch_link">
+          <a tal:attributes="href branch/branch_link"
+             tal:content="branch/friendly_name">
+            nice/branch/name
+          </a>
+        </tal:has-link>
+        <tal:no-link condition="not: branch/branch_link">
+          <span metal:use-macro="breadcrumbs/directory"></span>
+        </tal:no-link>
+        <tal:block condition="changes">
+          : changes
+          <tal:block condition="filter_file_id">to <span tal:content="python:history.get_path(revid, filter_file_id)" /></tal:block>
+          <tal:block condition="start_revid">from revision
+            <span tal:content="python:history.get_revno(start_revid)"/>
+          </tal:block>
+          <tal:block condition="query">matching <tal:block content="query" /></tal:block>
         </tal:block>
-
-        <div metal:fill-slot="content">
-          <tal:branch-info replace="structure python:branchinfo(branch)" />
-
-           <!-- Something nicer-looking should be done with search -->
-        <p tal:condition="search_failed">
-          Sorry, no results found for your search.
-        </p>
-
-        <p tal:condition="not:changes">
-          No revisions!
-        </p>
-
-        <p class="fr revnolink">From Revision <a tal:attributes="href #
-                                                            title python:'Show revision '+history.get_revno(revid)" 
-                                tal:content="python:history.get_revno(revid)"></a>
-          <tal:block tal:condition="python:navigation.last_in_page_revid is not None"> to
+      </h1>
+    </tal:block>
+
+    <div metal:fill-slot="content">
+      <tal:branch-info replace="structure python:branchinfo(branch)" />
+
+      <!-- Something nicer-looking should be done with search -->
+      <p tal:condition="search_failed">
+        Sorry, no results found for your search.
+      </p>
+
+      <p tal:condition="not:changes">
+        No revisions!
+      </p>
+
+      <p class="fr revnolink">From Revision <a tal:attributes="href #
+                                                               title python:'Show revision '+history.get_revno(revid)" 
+                                               tal:content="python:history.get_revno(revid)"></a>
+        <tal:block tal:condition="python:navigation.last_in_page_revid is not None"> to
           <a tal:attributes="href # 
                              title 'Show revision '+history.get_revno(navigation.last_in_page_revid)"
              tal:content="python:history.get_revno(navigation.last_in_page_revid)"></a>
-         </tal:block></p>
-        <p class="expand" id="expand_all"><a tal:attributes="href string:javascript:toggle_expand_all('open')">
-            <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
-                  alt="expand all" /> expand all</a>
-        </p>
-        <p class="expand" id="collapse_all" style="display:none;"><a tal:attributes="href string:javascript:toggle_expand_all('close')">
-            <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
-                  alt="collapse all" /> collapse all</a>
-        </p>
-        <!-- Table -->        
-        <table id="logentries">
-            <tr class="logheader">
-                <td class="revisionnumber">Rev</td>
-                <td class="expandcell">&nbsp;</td>
-                <td class="summarycell">Summary</td>
-                <td class="authorcell">Author</td>
-                <td class="datecell">Date</td>
-                <td class="diffcell">Diff</td>
-                <td class="downloadcell">Files</td>
-            </tr>
-            <tal:block tal:repeat="entry changes">
-            <a tal:attributes="name string:entry-${entry/revno}"/>
-                <tr tal:attributes="class string:blueRow${entry/parity} revision_log">
-                <td class="revnro revnolink"><a tal:attributes="title python:'Show revision '+entry.revno;
-                                                                href  python:url(['/revision', entry.revno], clear=1)"
-                                                tal:content="python:util.trunc(entry.revno)"></a>
-                </td>            
-                <td class="expcell">
-                    <div class="expand_revisioninfo">
-                        <!-- So, this is interesting. I'm using "alt" to have the correct URL for the image of the expanded icon
-                             and "title" tag for the contracted URL of the image. This is a bit of a hack, but it's better than
-                             other approaches I tried  :)  -->
-                        <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png');
-                                             alt python:branch.static_url('/static/images/treeExpanded.png');
-                                             title python:branch.static_url('/static/images/treeCollapsed.png')" 
-                             class="expand_icon" />
-                    </div>
-                </td>
-                <td class="summcell"><div tal:attributes="class string:short_description">
-                                        <a tal:attributes="title python:'Show revision '+entry.revno;
-                                                           href  python:url(['/revision', entry.revno], clear=1);
-                                                           class string:link"
-                                           tal:content="entry/short_comment"></a>
-                                     </div>
-                                     <div tal:attributes="class string:long_description;
-                                                          style string:display:none">
-                                        <a tal:attributes="title python:'Show revision '+entry.revno;
-                                                           href  python:url(['/revision', entry.revno], clear=1);
-                                                           class string:link"
-                                           tal:content="entry/comment"></a>
-                                     </div>
-                                <div class="revisioninfo" style="display:none;">
-                                    <ul class="expandrev">
-               	                        <li class="mfrom" tal:repeat="parent python:entry.parents[1:]">
-                                            <span class="revnolink">
-                                                <a tal:attributes="href python:url(['/changes', parent.revno])"
-                                                   tal:content="parent/revno"></a>
-                                            </span>
-                                            <a tal:condition="parent.branch_nick"
-                                               tal:attributes="href python:url(['/changes'], start_revid=parent.revno)"
-                                               tal:content="python:'(' + parent.branch_nick + ')'"
-                                                title="Show history" class="link"></a>
-                                        </li>
-               	                        <li class="mto" tal:repeat="merge_point entry/merge_points">
-                                            <a tal:attributes="href python:url(['/changes'], start_revid=merge_point.revno)"
-                                               tal:content="python:revno_with_nick(merge_point)"
-                                               title="Show history" class="link"></a>
-                                        </li>
-                                        <li class="committerli" tal:content="python:util.hide_email(entry.author)"></li>
-                                        <tal:block content="structure python:file_change_summary(url, entry, modified_file_link_log)" />
-                                    </ul>
-                                </div>
-                </td>
-                <td tal:content="python:util.trunc(util.hide_email(entry.author), 20)"
-                    class="autcell"></td>
-                <td class="date">
-                    <span tal:attributes="title python:util.date_time(entry.date)"
-                          tal:content="python:util._approximatedate(entry.date)"></span>
-                </td>
-                <td class="diffr"><a tal:attributes="title python:'Show diff at revision '+entry.revno;
-                                                     href python:url(['/revision', entry.revno], clear=1)">
-                                  <img tal:attributes="src python:branch.static_url('/static/images/ico_diff.gif')" alt="Diff" /></a></td>
-                <td class="downr"><a tal:attributes="href python:branch.url(['/files', entry.revno]);
-                                                     title string:Files at revision ${entry/revno}">
-                                   <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif')" alt="Files" /></a>
-                </td>
-            </tr>
-          </tal:block>
-        </table>
-
-        <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
-            id="pages">
-            <li tal:condition="navigation/prev_page_revid" 
-                class="previous">
-                <a tal:attributes="href navigation/prev_page_url">&laquo; Previous</a>
-            </li>
-            <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
-                        so some magic has to be done to just show the previous and next N page numbers
-
-            <li class="active">1</li>
-            <tal:block tal:repeat="page_number python:range(navigation.page_count)">
-            <li><a href="#"
-                   tal:content="page_number"></a></li>
-               </tal:block>-->
-            <li tal:condition="navigation/next_page_revid"
-                class="next">
-                <a tal:attributes="href navigation/next_page_url">Next &raquo;</a>
-            </li>
-        </ul>
-
-      </div>
-    </body>
-  </html>
-</tal:block>
+      </tal:block></p>
+      <p class="expand show_if_js" id="expand_all"><a href="#">
+          <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
+               alt="expand all" /> expand all</a>
+      </p>
+      <p class="expand" id="collapse_all" style="display:none;"><a href="#">
+          <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
+               alt="collapse all" /> collapse all</a>
+      </p>
+      <!-- Table -->        
+      <table id="logentries">
+        <tr class="logheader">
+          <td class="revisionnumber">Rev</td>
+          <td class="expandcell">&nbsp;</td>
+          <td class="summarycell">Summary</td>
+          <td class="authorcell">Author</td>
+          <td class="datecell">Date</td>
+          <td class="diffcell">Diff</td>
+          <td class="downloadcell">Files</td>
+        </tr>
+        <tal:block tal:repeat="entry changes">
+          <a tal:attributes="name string:entry-${entry/revno}"/>
+          <tr tal:attributes="class string:blueRow${entry/parity} revision_log">
+            <td class="revnro revnolink"><a tal:attributes="title python:'Show revision '+entry.revno;
+                                                            href  python:url(['/revision', entry.revno], clear=1)"
+                                            tal:content="python:util.trunc(entry.revno)"></a>
+            </td>            
+            <td class="expcell">
+              <div class="expand_revisioninfo">
+                <!-- So, this is interesting. I'm using "alt" to have the correct URL for the image of the expanded icon
+                     and "title" tag for the contracted URL of the image. This is a bit of a hack, but it's better than
+                     other approaches I tried  :)  -->
+                <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png');
+                                     alt python:branch.static_url('/static/images/treeExpanded.png');
+                                     title python:branch.static_url('/static/images/treeCollapsed.png')" 
+                     class="expand_icon" />
+              </div>
+            </td>
+            <td class="summcell"><div tal:attributes="class string:short_description">
+                <a tal:attributes="title python:'Show revision '+entry.revno;
+                                   href  python:url(['/revision', entry.revno], clear=1);
+                                   class string:link"
+                   tal:content="entry/short_comment"></a>
+              </div>
+              <div tal:attributes="class string:long_description;
+                                   style string:display:none">
+                <a tal:attributes="title python:'Show revision '+entry.revno;
+                                   href  python:url(['/revision', entry.revno], clear=1);
+                                   class string:link"
+                   tal:content="entry/comment"></a>
+              </div>
+              <div class="revisioninfo" style="display:none;">
+                <ul class="expandrev">
+               	  <li class="mfrom" tal:repeat="parent python:entry.parents[1:]">
+                    <span class="revnolink">
+                      <a tal:attributes="href python:url(['/changes', parent.revno])"
+                         tal:content="parent/revno"></a>
+                    </span>
+                    <a tal:condition="parent.branch_nick"
+                       tal:attributes="href python:url(['/changes'], start_revid=parent.revno)"
+                       tal:content="python:'(' + parent.branch_nick + ')'"
+                       title="Show history" class="link"></a>
+                  </li>
+               	  <li class="mto" tal:repeat="merge_point entry/merge_points">
+                    <a tal:attributes="href python:url(['/changes'], start_revid=merge_point.revno)"
+                       tal:content="python:revno_with_nick(merge_point)"
+                       title="Show history" class="link"></a>
+                  </li>
+                  <li class="committerli" tal:content="python:util.hide_email(entry.author)"></li>
+                  <tal:block content="structure python:file_change_summary(url, entry, modified_file_link_log)" />
+                </ul>
+              </div>
+            </td>
+            <td tal:content="python:util.trunc(util.hide_email(entry.author), 20)"
+                class="autcell"></td>
+            <td class="date">
+              <span tal:attributes="title python:util.date_time(entry.date)"
+                    tal:content="python:util._approximatedate(entry.date)"></span>
+            </td>
+            <td class="diffr"><a tal:attributes="title python:'Show diff at revision '+entry.revno;
+                                                 href python:url(['/revision', entry.revno], clear=1)">
+                <img tal:attributes="src python:branch.static_url('/static/images/ico_diff.gif')" alt="Diff" /></a></td>
+            <td class="downr"><a tal:attributes="href python:branch.url(['/files', entry.revno]);
+                                                 title string:Files at revision ${entry/revno}">
+                <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif')" alt="Files" /></a>
+            </td>
+          </tr>
+        </tal:block>
+      </table>
+
+      <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
+          id="pages">
+        <li tal:condition="navigation/prev_page_revid" 
+            class="previous">
+          <a tal:attributes="href navigation/prev_page_url">&laquo; Newer</a>
+        </li>
+        <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
+             so some magic has to be done to just show the previous and next N page numbers
+
+             <li class="active">1</li>
+             <tal:block tal:repeat="page_number python:range(navigation.page_count)">
+               <li><a href="#"
+                      tal:content="page_number"></a></li>
+             </tal:block>-->
+        <li tal:condition="navigation/next_page_revid"
+            class="next">
+          <a tal:attributes="href navigation/next_page_url">Older &raquo;</a>
+        </li>
+      </ul>
+
+    </div>
+  </body>
+</html>

=== modified file 'loggerhead/templates/inventory.pt'
--- loggerhead/templates/inventory.pt	2009-01-23 20:53:40 +0000
+++ loggerhead/templates/inventory.pt	2009-02-10 04:25:11 +0000
@@ -64,7 +64,7 @@
 
             <!-- Show this if it's a directory -->
             <tal:block repeat="file filelist">
-            <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='directory'">
+            <tr tal:attributes="class string:blueRow${repeat/file/even}" tal:condition="python:file.kind=='directory'">
                 <td class="autcell"><a tal:attributes="href python:url(['/files', revno_url, file.absolutepath])">
                         <img tal:attributes="src python:branch.static_url('/static/images/ico_folder.gif');
                                              title string:Go to ${file/filename}" />
@@ -88,7 +88,7 @@
             </tr>
 
             <!-- Show this if it's a symlink -->
-            <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='symlink'">
+            <tr tal:attributes="class string:blueRow${repeat/file/even}" tal:condition="python:file.kind=='symlink'">
                 <td class="autcell"><a tal:attributes="href python:url(['/annotate', change.revno, file.absolutepath])">
                         <img tal:attributes="src python:branch.static_url('/static/images/ico_flecha.gif')" alt="Symlink" />
                     </a>
@@ -112,7 +112,7 @@
             </tr>
 
             <!-- Show this if it's a regular file -->
-            <tr tal:attributes="class string:blueRow${file/parity}" tal:condition="python:file.kind=='file'">
+            <tr tal:attributes="class string:blueRow${repeat/file/even}" tal:condition="python:file.kind=='file'">
                 <td class="autcell"><a tal:attributes="href python:url(['/annotate', revno_url, file.absolutepath])">
                         <img tal:attributes="src python:branch.static_url('/static/images/ico_file.gif');
                                              title string:Annotate ${file/filename}"

=== modified file 'loggerhead/templates/macros.pt'
--- loggerhead/templates/macros.pt	2008-10-25 18:41:18 +0000
+++ loggerhead/templates/macros.pt	2009-02-26 01:04:18 +0000
@@ -7,18 +7,40 @@
     <title metal:define-slot="title"></title>
     <link rel="stylesheet"
           tal:attributes="href python:branch.static_url('/static/css/global.css')" />
-    <script type="text/javascript"
-            tal:attributes="src python:branch.static_url('/static/javascript/mootools-1.2-core.js')"></script>
-    <script type="text/javascript"
-            tal:attributes="src python:branch.static_url('/static/javascript/mootools-1.2-more.js')"></script>
+<!-- <script type="text/javascript"
+            src="http://getfirebug.com/releases/lite/1.2/firebug-lite-compressed.js"></script> -->
+    <script type="text/javascript">
+      var global_path = <tal:block content="python:'\''+branch.url('/')+'\''" />;
+    </script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/yui/yui-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/oop/oop-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/event/event-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/attribute/attribute-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/base/base-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/dom/dom-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/node/node-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/anim/anim-min.js')"></script>
+    <script type="text/javascript"
+            tal:attributes="src
+            python:branch.static_url('/static/javascript/yui/build/io/io-base-min.js')"></script>
     <script type="text/javascript"
             tal:attributes="src python:branch.static_url('/static/javascript/custom.js')"></script>
-      <script type="text/javascript">
-          var global_path = <tal:block content="python:'\''+branch.url('/')+'\''" />;
-      </script>
-      <script type="text/javascript"
-              tal:attributes="src
-              python:branch.static_url('/static/javascript/yui/build/yui/yui-min.js')"></script>
     <metal:block metal:define-slot="header_extras" />
   </head>
 

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2009-01-23 20:53:40 +0000
+++ loggerhead/templates/revision.pt	2009-02-26 21:01:19 +0000
@@ -9,6 +9,8 @@
       <metal:block fill-slot="header_extras">
         <link rel="stylesheet" type="text/css" media="all"
               tal:attributes="href python:branch.static_url('/static/css/diff.css')"/>
+        <script type="text/javascript"
+                tal:attributes="src python:branch.static_url('/static/javascript/diff.js')"></script>
       </metal:block>
     </head>
 
@@ -26,60 +28,61 @@
             <span metal:use-macro="breadcrumbs/directory"></span>
           </tal:no-link>
           <span>: <tal:revno content="change/revno"></tal:revno>
-        <tal:compare-to condition="python:compare_revid is not None">
-          (compared to revision <tal:block content="python:history.get_revno(compare_revid)" />)
-          </tal:compare-to>
+            <tal:compare-to condition="python:compare_revid is not None">
+              (compared to revision <tal:block content="python:history.get_revno(compare_revid)" />)
+            </tal:compare-to>
         </span></h1>
         <tal:branch-info replace="structure python:branchinfo(branch)" />
         <ul id="submenuTabs">
-            <li id="first"><a tal:attributes="href python:url(['/files', change.revno]); 
-                                               title string:browse files at revision ${change/revno}"
-                               tal:content="string:browse files at revision ${change/revno}"></a></li>
-            <li tal:condition="python:remember != change.revno">
-                <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None); 
-                                   title string:compare with another revision"
-                   tal:content="string:Compare with another revision"></a></li>       
-            <li tal:condition="python:(remember is not None) and (compare_revid is None) and (change.revno != remember)" >
-                <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
-                compare with revision <tal:b content="python:history.get_revno(remember)" />
-                </a>
-            </li>
-            <li>
+          <li id="first"><a tal:attributes="href python:url(['/files', change.revno]);
+                                            title string:browse files at revision ${change/revno}"
+                            tal:content="string:browse files at revision ${change/revno}"></a></li>
+          <li tal:condition="python:remember != change.revno">
+            <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None);
+                               title string:compare with another revision"
+               tal:content="string:Compare with another revision"></a></li>
+          <li tal:condition="python:(remember is not None) and (compare_revid is None) and (change.revno != remember)" >
+            <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
+              compare with revision <tal:b content="python:history.get_revno(remember)" />
+            </a>
+          </li>
+          <li>
             <a tal:condition="python:len(change.parents) > 0 and compare_revid is None"
-                   tal:attributes="href python:url(['/diff', change.revno], clear=1)">download diff</a>
+               tal:attributes="href python:url(['/diff', change.revno], clear=1)">download diff</a>
             <a tal:condition="python:compare_revid is not None"
-                   tal:attributes="href python:url(['/diff', change.revno, history.get_revno(compare_revid)], clear=1)">download diff</a>
-            </li>
-            <li id="last"><a tal:attributes="href python:url(['/changes', change.revno]); 
-                                  title string:view history from revision ${change/revno}"
-                  tal:content="string:view history from revision ${change/revno}"></a></li>
+               tal:attributes="href python:url(['/diff', change.revno, history.get_revno(compare_revid)], clear=1)">download diff</a>
+          </li>
+          <li id="last"><a tal:attributes="href python:url(['/changes', change.revno]);
+                                           title string:view history from revision ${change/revno}"
+                           tal:content="string:view history from revision ${change/revno}"></a></li>
         </ul>
 
         <tal:we-are-comparing condition="python:compare_revid is not None">
-        <ul id="submenuTabs">
-          <li id="first">
+          <ul id="submenuTabs">
+            <li id="first">
               <a tal:attributes="href python:url([ '/revision', history.get_revno(compare_revid) ], remember=change.revno, compare_revid=change.revno)">
                 reverse the comparison (<tal:b content="change/revno" /> to <tal:b content="python:history.get_revno(compare_revid)" />)
               </a>
-          </li>
-          <li id="last">
+            </li>
+            <li id="last">
               <a tal:attributes="href python:url(['/revision', change.revno], remember=None, compare_revid=None)">
                 stop comparing with revision <tal:b content="python:history.get_revno(compare_revid)" />
               </a>
-          </li>
-        </ul>
+            </li>
+          </ul>
         </tal:we-are-comparing>
-        
+
         <tal:revision-info replace="structure python:revisioninfo(url, branch, change, modified_file_link_rev)" />
-        <p class="expand" id="expand_all" style="display:none;"><a tal:attributes="href string:javascript:toggle_expand_all_revisionview('open')">
+        <p class="expand" id="expand_all" style="display:none;"><a href="#">
             <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
-                  alt="expand all" /> expand all</a>
+                 alt="expand all" /> expand all</a>
         </p>
-        <p class="expand" id="collapse_all"><a tal:attributes="href string:javascript:toggle_expand_all_revisionview('close')">
+        <p class="expand show_if_js" id="collapse_all"><a href="#">
             <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
-                  alt="collapse all" /> collapse all</a>
+                 alt="collapse all" /> collapse all</a>
         </p>
-        <!-- Table -->        
+        <!-- Table -->
+        <p class="expand show_if_js"><a id="toggle_unified_sbs" href="#">Show diffs side-by-side</a></p>
         <p class="codin"><img tal:attributes="src python:branch.static_url('/static/images/newCode.gif')" alt="added" /> added</p>
         <p class="codin"><img tal:attributes="src python:branch.static_url('/static/images/deleteCode.gif')" alt="removed" /> removed</p>
         <div class="clear"><!-- --></div>
@@ -88,87 +91,64 @@
 
       <div metal:fill-slot="content">
         <div class="diff"
-             tal:condition="change/changes/modified"
-             tal:define="uniqs python:{}">
-          <!-- ! side-by-side diff -->
-          <tal:block repeat="item change/changes/modified">
-
-              <tal:u define="u python:util.uniq(uniqs, item.file_id)">
-                      <div class="diffBox"><img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png');
-                                                                title python:branch.static_url('/static/images/treeCollapsed.png');
-                                                                alt python:branch.static_url('/static/images/treeExpanded.png')"
-                                                                class="expand_diff" />
-                                           <a tal:attributes="href python:url(['/annotate', change.revno], clear=1, file_id=item.file_id);
-                                                              id string:${item/filename}-s;
-                                                              title string:Annotate ${item/filename}"
-                                              tal:content="item/filename"></a></div>
-               <div id="psuedotable" class="diffinfo">
-               <tal:block repeat="chunk item/sbs_chunks">
-
-                <tal:block condition="not:repeat/chunk/start">
-                 <div class="lineNumber separate"></div>
-                 <div class="lineCode separate"></div>
-                 <div class="lineNumber separate"></div>
-                 <div class="lineCode separate"></div>
-                 <div class="clear"><!-- --></div>
-                </tal:block>
-
-                <tal:block repeat="line chunk/diff">
-                    <div id="pseudorow">
-                    <tal:block condition="line/old_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.old_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/old_type}">
-                            <tal:block replace="structure python:util.fill_div(line.old_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="not:line/old_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.old_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/old_type}">
-                            <tal:block replace="structure python:util.fill_div(line.old_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="line/new_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.new_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/new_type}">
-                            <tal:block replace="structure python:util.fill_div(line.new_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="not:line/new_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.new_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/new_type}">
-                            <tal:block replace="structure python:util.fill_div(line.new_line)" />
-                        </div>
-                    </tal:block>
-                    <div class="clear"><!-- --></div>
-                    </div>
-                   </tal:block>
-                 </tal:block>
-                 </div>
-              </tal:u>
-            </tal:block>
+             tal:repeat="item change/changes/modified">
+
+          <div class="diffBox">
+            <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png');
+                                 title python:branch.static_url('/static/images/treeCollapsed.png');
+                                 alt python:branch.static_url('/static/images/treeExpanded.png')"
+                 class="expand_diff" />
+            <a tal:attributes="href python:url(['/annotate', change.revno], clear=1, file_id=item.file_id);
+                               id string:${item/filename}-s;
+                               title string:Annotate ${item/filename}"
+               tal:content="item/filename">
+            </a>
+          </div>
+          <div class="diffinfo">
+            <div class="pseudotable unified"
+                 tal:repeat="chunk item/chunks">
+
+              <tal:block condition="not:repeat/chunk/start">
+                <div class="pseudorow context">
+                  <div class="lineNumber separate"></div>
+                  <div class="lineNumber second separate"></div>
+                  <div class="code separate"></div>
+                  <div class="clear"><!-- --></div>
+                </div>
+              </tal:block>
+
+              <div tal:repeat="line chunk/diff"
+                   tal:attributes="class string:pseudorow ${line/type}-row">
+                <div class="lineNumber first"
+                     tal:content="structure python:util.fill_div(line.old_lineno)"></div>
+                <div class="lineNumber second"
+                     tal:content="structure python:util.fill_div(line.new_lineno)"></div>
+                <div tal:attributes="class string:code ${line/type}"
+                     tal:content="structure python:util.fill_div(util.html_clean(line.line))"></div>
+                <div class="clear"><!-- --></div>
+              </div>
+            </div>
+          </div>
         </div>
 
         <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
             id="pages">
-            <li tal:condition="navigation/prev_page_revid" 
-                class="previous">
-                <a tal:attributes="href navigation/prev_page_url">&laquo; Previous</a>
-            </li>
-            <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
-                        so some magic has to be done to just show the previous and next N page numbers
+          <li tal:condition="navigation/prev_page_revid"
+              class="previous">
+            <a tal:attributes="href navigation/prev_page_url">&laquo; Newer</a>
+          </li>
+          <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
+               so some magic has to be done to just show the previous and next N page numbers
 
-            <li class="active">1</li>
-            <tal:block tal:repeat="page_number python:range(navigation.page_count)">
-            <li><a href="#"
-                   tal:content="page_number"></a></li>
+               <li class="active">1</li>
+               <tal:block tal:repeat="page_number python:range(navigation.page_count)">
+                 <li><a href="#"
+                        tal:content="page_number"></a></li>
                </tal:block>-->
-            <li tal:condition="navigation/next_page_revid"
-                class="next">
-                <a tal:attributes="href navigation/next_page_url">Next &raquo;</a>
-            </li>
+          <li tal:condition="navigation/next_page_revid"
+              class="next">
+            <a tal:attributes="href navigation/next_page_url">Older &raquo;</a>
+          </li>
         </ul>
 
       </div>

=== added file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	1970-01-01 00:00:00 +0000
+++ loggerhead/tests/test_controllers.py	2009-02-23 20:32:43 +0000
@@ -0,0 +1,79 @@
+from loggerhead.apps.branch import BranchWSGIApp
+from loggerhead.controllers.annotate_ui import AnnotateUI
+from loggerhead.controllers.inventory_ui import InventoryUI
+from loggerhead.controllers.revision_ui import RevisionUI
+from loggerhead.tests.test_simple import BasicTests
+from loggerhead import util
+
+
+class TestInventoryUI(BasicTests):
+
+    def make_bzrbranch_and_inventory_ui_for_tree_shape(self, shape):
+        tree = self.make_branch_and_tree('.')
+        self.build_tree(shape)
+        tree.smart_add([])
+        tree.commit('')
+        tree.branch.lock_read()
+        self.addCleanup(tree.branch.unlock)
+        branch_app = BranchWSGIApp(tree.branch)
+        return tree.branch, InventoryUI(branch_app, branch_app.get_history)
+
+    def test_get_filelist(self):
+        bzrbranch, inv_ui = self.make_bzrbranch_and_inventory_ui_for_tree_shape(
+            ['filename'])
+        inv = bzrbranch.repository.get_inventory(bzrbranch.last_revision())
+        self.assertEqual(1, len(inv_ui.get_filelist(inv, '', 'filename')))
+
+
+class TestRevisionUI(BasicTests):
+
+    def make_bzrbranch_and_revision_ui_for_tree_shapes(self, shape1, shape2):
+        tree = self.make_branch_and_tree('.')
+        self.build_tree_contents(shape1)
+        tree.smart_add([])
+        tree.commit('')
+        tree.smart_add([])
+        self.build_tree_contents(shape2)
+        tree.commit('')
+        tree.branch.lock_read()
+        self.addCleanup(tree.branch.unlock)
+        branch_app = BranchWSGIApp(tree.branch)
+        branch_app._environ = {
+            'wsgi.url_scheme':'',
+            'SERVER_NAME':'',
+            'SERVER_PORT':'80',
+            }
+        branch_app._url_base = ''
+        branch_app.friendly_name = ''
+        return tree.branch, RevisionUI(branch_app, branch_app.get_history)
+
+    def test_get_values(self):
+        branch, rev_ui = self.make_bzrbranch_and_revision_ui_for_tree_shapes(
+            [], [])
+        rev_ui.args = ['2']
+        util.set_context({})
+        self.assertIsInstance(
+            rev_ui.get_values('2', {}, []),
+            dict)
+
+class TestAnnotateUI(BasicTests):
+
+    def make_annotate_ui_for_file_history(self, file_id, rev_ids_texts):
+        tree = self.make_branch_and_tree('.')
+        open('filename', 'w').write('')
+        tree.add(['filename'], [file_id])
+        for rev_id, text in rev_ids_texts:
+            open('filename', 'w').write(text)
+            tree.commit(rev_id=rev_id, message='.')
+        tree.branch.lock_read()
+        self.addCleanup(tree.branch.unlock)
+        branch_app = BranchWSGIApp(tree.branch)
+        return AnnotateUI(branch_app, branch_app.get_history)
+
+    def test_annotate_file(self):
+        history = [('rev1', 'old\nold\n'), ('rev2', 'new\nold\n')]
+        ann_ui = self.make_annotate_ui_for_file_history('file_id', history)
+        annotated = list(ann_ui.annotate_file('file_id', 'rev2'))
+        self.assertEqual(2, len(annotated))
+        self.assertEqual('2', annotated[0].change.revno)
+        self.assertEqual('1', annotated[1].change.revno)

=== modified file 'loggerhead/tests/test_corners.py'
--- loggerhead/tests/test_corners.py	2008-06-20 02:20:05 +0000
+++ loggerhead/tests/test_corners.py	2009-02-10 01:58:31 +0000
@@ -12,11 +12,7 @@
         The commit adds a file called 'myfilename' containing the string
         'foo'.
         """
-        f = open(os.path.join(self.bzrbranch, filename), 'w')
-        try:
-            f.write("foo")
-        finally:
-            f.close()
+        self.build_tree_contents([(filename, 'foo')])
         self.tree.add(filename)
         self.tree.commit(message=commit_msg)
 
@@ -30,7 +26,7 @@
         self.addFileAndCommit('myfilename', msg)
 
         # Make a commit that changes the execute bit of 'myfilename'.
-        os.chmod(os.path.join(self.bzrbranch, 'myfilename'), 0755)
+        os.chmod('myfilename', 0755)
         newrevid = self.tree.commit(message='make something executable')
 
         # Check that it didn't break things.

=== modified file 'loggerhead/tests/test_simple.py'
--- loggerhead/tests/test_simple.py	2009-02-10 01:57:06 +0000
+++ loggerhead/tests/test_simple.py	2009-02-18 10:40:22 +0000
@@ -1,35 +1,36 @@
 import cgi
-import os
-import tempfile
-import shutil
 import logging
 
-import bzrlib.bzrdir
-import bzrlib.osutils
 from bzrlib.tests import TestCaseWithTransport
 from bzrlib.util.configobj.configobj import ConfigObj
 
 from loggerhead.apps.branch import BranchWSGIApp
 from paste.fixture import TestApp
+from paste.httpexceptions import HTTPExceptionHandler
+
 
 
 def test_config_root():
     from loggerhead.apps.config import Root
     config = ConfigObj()
-    app = TestApp(Root(config))
+    app = TestApp(HTTPExceptionHandler(Root(config)))
     res = app.get('/')
     res.mustcontain('loggerhead branches')
 
 
 class BasicTests(TestCaseWithTransport):
 
+    def setUp(self):
+        TestCaseWithTransport.setUp(self)
+        logging.basicConfig(level=logging.ERROR)
+        logging.getLogger('bzr').setLevel(logging.CRITICAL)
 
     def createBranch(self):
         self.tree = self.make_branch_and_tree('.')
 
-    def setUpLoggerhead(self):
-        app = TestApp(BranchWSGIApp(self.tree.branch, '').app)
-        return app
+    def setUpLoggerhead(self, **kw):
+        branch_app = BranchWSGIApp(self.tree.branch, '', **kw).app
+        return TestApp(HTTPExceptionHandler(branch_app))
 
 
 class TestWithSimpleTree(BasicTests):
@@ -52,6 +53,15 @@
         res = app.get('/changes')
         res.mustcontain(cgi.escape(self.msg))
 
+    def test_changes_branch_from(self):
+        app = self.setUpLoggerhead(served_url="lp:loggerhead")
+        res = app.get('/changes')
+        self.failUnless("To get this branch, use:" in res)
+        self.failUnless("lp:loggerhead" in res)
+        app = self.setUpLoggerhead(served_url=None)
+        res = app.get('/changes')
+        self.failIf("To get this branch, use:" in res)
+
     def test_changes_search(self):
         app = self.setUpLoggerhead()
         res = app.get('/changes', params={'q': 'foo'})
@@ -67,6 +77,24 @@
         app = self.setUpLoggerhead()
         res = app.get('/files')
         res.mustcontain('myfilename')
+        res = app.get('/files/')
+        res.mustcontain('myfilename')
+        res = app.get('/files/1')
+        res.mustcontain('myfilename')
+        res = app.get('/files/1/')
+        res.mustcontain('myfilename')
+        res = app.get('/files/1/?file_id=' + self.tree.path2id(''))
+        res.mustcontain('myfilename')
+
+    def test_inventory_bad_rev_404(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/files/200', status=404)
+        res = app.get('/files/invalid-revid', status=404)
+
+    def test_inventory_bad_path_404(self):
+        app = self.setUpLoggerhead()
+        res = app.get('/files/1/hooha', status=404)
+        res = app.get('/files/1?file_id=dssadsada', status=404)
 
     def test_revision(self):
         app = self.setUpLoggerhead()
@@ -84,9 +112,9 @@
         app = self.setUpLoggerhead()
         res = app.get('/changes')
         res.mustcontain('No revisions!')
-    
+
     def test_inventory(self):
         app = self.setUpLoggerhead()
         res = app.get('/files')
-        res.mustcontain('myfilename')
+        res.mustcontain('No revisions!')
 

=== modified file 'serve-branches'
--- serve-branches	2009-02-04 22:41:28 +0000
+++ serve-branches	2009-02-24 21:13:30 +0000
@@ -21,6 +21,8 @@
 
 from optparse import OptionParser
 
+from bzrlib.plugin import load_plugins
+
 from paste import httpserver
 from paste.httpexceptions import HTTPExceptionHandler, HTTPInternalServerError
 from paste.translogger import TransLogger
@@ -125,6 +127,8 @@
         prefix = '/'
     else:
         prefix = options.user_prefix
+        if not prefix.startswith('/'):
+            prefix = '/' + prefix
 
     try:
         from paste.deploy.config import PrefixMiddleware
@@ -144,8 +148,8 @@
     else:
         app = PrefixMiddleware(app, prefix=prefix)
 
+    app = HTTPExceptionHandler(app)
     app = ErrorHandlerApp(app)
-    app = HTTPExceptionHandler(app)
 
     if not options.user_port:
         port = '8080'
@@ -157,6 +161,8 @@
     else:
         host = options.user_host
 
+    load_plugins()
+
     httpserver.serve(app, host=host, port=port)
 
 

=== modified file 'start-loggerhead'
--- start-loggerhead	2009-02-10 01:25:34 +0000
+++ start-loggerhead	2009-02-19 01:24:20 +0000
@@ -23,6 +23,7 @@
 import sys
 import urlparse
 
+from bzrlib.plugin import load_plugins
 from bzrlib.util.configobj.configobj import ConfigObj
 
 from paste import httpserver
@@ -118,6 +119,8 @@
             environ['wsgi.url_scheme'] = scheme
             return orig(environ, start_response)
 
+    load_plugins()
+
     try:
         httpserver.serve(
             app, host=server_host, port=server_port,

